/* Ui Callbacks 
 * $Id: callbacks.c,v 1.27 2000/04/30 17:21:09 marijn Exp $

 * An air traffic simulation game. 
 * Copyright (C) 2000  Marijn Vriens <marijn@sanity.dhs.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gnome.h>

#include "defaults.h"
#include "datastructs.h"
#include "init.h"
#include "game.h"
#include "tests.h"
#include "prefs.h"
#include "utils.h"
#include "callbacks.h"
#include "interface.h"

/* menubar callbacks */

void
on_menubar1_selection_done             (GtkMenuShell    *menushell,
                                        gpointer         user_data)
{

}


void /* start a new game */
on_new_game_activate                  (GtkMenuItem     *menuitem,
				       gpointer         user_data)
{
	gameStart();
	gameRound();
}

void /* start a new game */
on_end_game_activate                  (GtkMenuItem     *menuitem,
				       gpointer         user_data)
{
	gameEnd(TRUE);
}


void
on_preferences_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	if(airUi->winPref == NULL) {
/* create a new settings structure */
		airUi->pref.set= initSettings(); 
		airUi->winPref = create_winPref(airUi, airSet);


	}
	gameEnd(FALSE);
     	gtk_widget_show(airUi->winPref);
} 


void
on_quit_activate                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	prefWrite(airSet);
	gtk_main_quit();
}


void
on_help1_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{

}


void
on_about_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	build_about_win();
}

/* Flightlist callbacks */

gboolean
on_time_key_press_event                (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data)
{
  
	return FALSE;
}


void
on_flightlist_select_row               (GtkCList        *clist,
                                        gint             row,
                                        gint             column,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{
	gint heading = 1;

	airUi->select = gtk_clist_get_row_data( GTK_CLIST(airUi->flist), row );
	g_assert(airUi->select);

	/* if the plane is not in the game yet, unselect the row. */
	if( airUi->select->widget == NULL ) {
		gtk_clist_unselect_row(GTK_CLIST(airUi->flist), row, 0);
		return;
	}
	
	if( airUi->select != NULL ) { /* change the look of the plane */
		if( testPlaneCourseChange(airUi->select) ) {
			move_plane(airUi->select, IMG_NORMAL, TRUE);
		} else {
			move_plane(airUi->select, IMG_CHANGE, TRUE);
		}
	}
	
	gtk_widget_set_sensitive( GTK_WIDGET(airUi->ctrl.n),  TRUE);
	gtk_widget_set_sensitive( GTK_WIDGET(airUi->ctrl.ne), TRUE);
	gtk_widget_set_sensitive( GTK_WIDGET(airUi->ctrl.e),  TRUE);
	gtk_widget_set_sensitive( GTK_WIDGET(airUi->ctrl.se), TRUE);
	gtk_widget_set_sensitive( GTK_WIDGET(airUi->ctrl.s),  TRUE);
	gtk_widget_set_sensitive( GTK_WIDGET(airUi->ctrl.sw), TRUE);
	gtk_widget_set_sensitive( GTK_WIDGET(airUi->ctrl.w),  TRUE);
	gtk_widget_set_sensitive( GTK_WIDGET(airUi->ctrl.nw), TRUE);
	gtk_widget_set_sensitive( GTK_WIDGET(airUi->ctrl.h),  TRUE);
	
	/* setting up the UI so that it represents the plane
	 * height  */
	if(airUi->select->cmd.z == -1) {
		gtk_adjustment_set_value (GTK_ADJUSTMENT (airUi->ctrl.hAdj),
					  AIR_BOARD_Z - (airUi->select->pos.z+1 ) );
		g_assert(airUi->select->pos.z != -1);
	} else {	
		gtk_adjustment_set_value (GTK_ADJUSTMENT (airUi->ctrl.hAdj), 
					  AIR_BOARD_Z - (airUi->select->cmd.z+1) );
		g_assert(airUi->select->cmd.z != -1);
	}
	/* direction switches */
	if(airUi->select->cmd.heading == -1) {
		heading = airUi->select->pos.heading;
	} else {
		heading = airUi->select->cmd.heading;
	}
	switch(heading) {
	case 0:
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (airUi->ctrl.n), TRUE);
		break;
	case 45:
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (airUi->ctrl.ne), TRUE);
		break;
	case 90:
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (airUi->ctrl.e), TRUE);
		break;
	case 135:
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (airUi->ctrl.se), TRUE);
		break;
	case 180:
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (airUi->ctrl.s), TRUE);
		break;
	case 225:
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (airUi->ctrl.sw), TRUE);
		break;
	case 270:
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (airUi->ctrl.w), TRUE);
		break;
	case 315:
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (airUi->ctrl.nw), TRUE);
		break;
	default:
		g_assert_not_reached();
	}

	/* update the plane image to active */
	move_plane(airUi->select, IMG_ACTIVE, TRUE);
}


void
on_flightlist_unselect_row             (GtkCList        *clist,
                                        gint             row,
                                        gint             column,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{

	/* disable all the controls */
	gtk_widget_set_sensitive( GTK_WIDGET(airUi->ctrl.n),  FALSE);
	gtk_widget_set_sensitive( GTK_WIDGET(airUi->ctrl.ne), FALSE);
	gtk_widget_set_sensitive( GTK_WIDGET(airUi->ctrl.e),  FALSE);
	gtk_widget_set_sensitive( GTK_WIDGET(airUi->ctrl.se), FALSE);
	gtk_widget_set_sensitive( GTK_WIDGET(airUi->ctrl.s),  FALSE);
	gtk_widget_set_sensitive( GTK_WIDGET(airUi->ctrl.sw), FALSE);
	gtk_widget_set_sensitive( GTK_WIDGET(airUi->ctrl.w),  FALSE);
	gtk_widget_set_sensitive( GTK_WIDGET(airUi->ctrl.nw), FALSE);
	gtk_widget_set_sensitive( GTK_WIDGET(airUi->ctrl.h),  FALSE);

	/* update the plane image to inactive */
	if( airUi->select != NULL ) {
		if(airUi->select->widget == NULL) return;
		if( testPlaneCourseChange(airUi->select) ) {
			move_plane(airUi->select, IMG_NORMAL, TRUE);
		} else {
			move_plane(airUi->select, IMG_CHANGE, TRUE);
		}
		airUi->select = NULL;
	}

	
//	g_print("Row %d unselected\n", row);
}


gboolean
on_hscale_value_change                 (GtkAdjustment   *adj )
{
	static gchar textbuff[3];
	gint  value, z;
	
	value = (gint) adj->value;
	z     = AIR_BOARD_Z - value -1;
	if(z < 0) { z=0; };
	
	if(airUi->select == NULL) {
//		g_print("NO PLANE SELECTED\n");
		return TRUE;
	}
	
	if( z == 0) { /* if the plane is at landing height */
		g_snprintf (textbuff, 3, "%s", _("L")); 
	} else {
		g_snprintf (textbuff, 3, "%d", z);
	}
	gtk_label_set_text (GTK_LABEL(airUi->ctrl.hLabel), textbuff );
	
	if(airUi->select != NULL) {
		airUi->select->cmd.z = z;
	}
	if(airUi->select->cmd.heading != -1) { /* there was a command given */
		plane_dir_change(airUi->select->cmd.heading);
	} else { /* there was a no given */
		plane_dir_change(airUi->select->pos.heading);
	}
//	g_print("Height call back, with Z=%d and value=%d\n", z, value);
	return FALSE;
}



/* Direction Control buttons */
void
on_toggDir_toggled                     (GtkToggleButton *togglebutton,
                                        gpointer         direction)
{
	plane_dir_change(GPOINTER_TO_INT(direction));
}

void /* nutral position, for heli only */
on_toggC_toggled                       (GtkToggleButton *togglebutton,
                                        gpointer         user_data)
{

}


void /* Left rotating pattern */
on_toggRL_toggled                      (GtkToggleButton *togglebutton,
                                        gpointer         user_data)
{

}

void /* Right rotating pattern */
on_toggRR_toggled                      (GtkToggleButton *togglebutton,
                                        gpointer         user_data)
{

}


void /* parking grid button */
on_toggPark_toggled                    (GtkToggleButton *togglebutton,
                                        gpointer         user_data)
{

}


/* board callbacks */

void /* click a plane */
board_plane_click (GtkButton *button,
		   gpointer data)
{
	gint row;

	g_assert(button);
	g_assert(data);

	row = gtk_clist_find_row_from_data( GTK_CLIST( airUi->flist ), data );
	gtk_clist_select_row( GTK_CLIST(airUi->flist), row, 0);
}



/* Time Control buttons */
gboolean
on_roundtime_button_release_event      (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data)
{
	g_print("Round ends now!\n");
	airSet->stat.progress = 1;
	game_time_passed(NULL);
	return FALSE;
}

/* time callbacks */
gint
game_time_passed(gpointer data)
{
	gfloat step =  ITERATIONSPEED / ( (gfloat) airSet->roundSpeed * 1000 );
	airSet->stat.progress += step;
	if(airSet->stat.progress >= 1) { /* if a round has been completed */
//		g_print("\nNew Round stared!\n");
		airSet->stat.progress = 0;
		gameRound();
		if(airPlanes == NULL) {
			gameEnd(TRUE);
		} else {
			/* update the list with plane info in the UI */
			loadFlightList(GTK_CLIST(airUi->flist), airPlanes);
		}
	} 
	gtk_progress_bar_update(GTK_PROGRESS_BAR(airUi->ctrl.time), airSet->stat.progress );
/*	g_print("Progress %g\n", airSet->stat.progress); */
	return TRUE;
}

void
checkJetPlane_toggled                  (GtkToggleButton *togglebutton,
                                        gpointer         user_data)
{

}

/* Ctrlwin WM signals */

gint cntl_win_close_btn_clicked (GtkWidget *widget,
				 GdkEvent  *event,
				 gpointer  data)
{
	gtk_main_quit();
	return(FALSE);
}

/* preferences window */

gboolean /* a hairy function, it updates the various structures with the changed points
	  * adj is the ajustment. var is the variable that needs to be set in the
	  * airSettings strcuture */
pref_on_game_value_change            (GtkAdjustment *adj, gpointer *var)
{
	gchar buff[12];
	gint  pts, maxPts, *v;

	g_assert(adj);
	g_assert(var);
	
	v = (gint *) var; /* derefing a void* pointer! */
	*v = adj->value;
	pts    =  calc_plane_score(airUi->pref.set);
	maxPts =  calc_max_score(airUi->pref.set);
//	g_print("v = %x, airUi->pref.set->airportNr= %x\n", v, &airUi->pref.set->airportNr);
	
	airUi->pref.set->score.planeval = pts;

	g_snprintf(buff, 11, "%d", pts);
//	g_print("pts = %s, maxPts = %d, *v=%x, v=%d\n", buff, maxPts, v, *v);
	gtk_label_set_text(GTK_LABEL(airUi->pref.pointsPerPlane), buff);
	g_snprintf(buff, 11, "%d", maxPts);
	gtk_label_set_text(GTK_LABEL(airUi->pref.pointsMax), buff);

	return FALSE;
}

gboolean
pref_on_reliability_value_change       (GtkAdjustment   *adj)
{ 

	return FALSE;
}

void
pref_on_objJetplane_toggled                 (GtkToggleButton *togglebutton,
					     gpointer         user_data)
{
	if(airUi->pref.set->objJetplane) {
		airUi->pref.set->objJetplane = TRUE;
	} else {
		airUi->pref.set->objJetplane = FALSE;
	}
}


void
pref_on_objPropPlanes_toggled               (GtkToggleButton *togglebutton,
					     gpointer         user_data)
{
	if(airUi->pref.set->objPropPlanes) {
		airUi->pref.set->objPropPlanes = TRUE;
	} else {
		airUi->pref.set->objPropPlanes = FALSE;
	}	
}

void
pref_on_objHelicopters_toggled              (GtkToggleButton *togglebutton,
                                             gpointer         user_data)
{
	if(airUi->pref.set->objHelicopters) {
		airUi->pref.set->objHelicopters = TRUE;
	} else {
		airUi->pref.set->objHelicopters = FALSE;
	}		
}

void
pref_on_objNoflyzones_toggled               (GtkToggleButton *togglebutton,
					     gpointer         user_data)
{
	if(airUi->pref.set->objNoflyzones) {
		airUi->pref.set->objNoflyzones = TRUE;
	} else {
		airUi->pref.set->objNoflyzones = FALSE;
	}			
}

void
pref_on_objStormSystem_toggled              (GtkToggleButton *togglebutton,
					     gpointer         user_data)
{
	if(airUi->pref.set->objStormSystem) {
		airUi->pref.set->objStormSystem = TRUE;
	} else {
		airUi->pref.set->objStormSystem = FALSE;
	}				
}

void
pref_on_objPowerCables_toggled              (GtkToggleButton *togglebutton,
					     gpointer         user_data)
{
	if(airUi->pref.set->objPowerCables) {
		airUi->pref.set->objPowerCables = TRUE;
	} else {
		airUi->pref.set->objPowerCables = FALSE;
	}					
}

void
pref_on_objGroundFog_toggled                (GtkToggleButton *togglebutton,
					     gpointer         user_data)
{
	if(airUi->pref.set->objGroundFog) {
		airUi->pref.set->objGroundFog = TRUE;
	} else {
		airUi->pref.set->objGroundFog = FALSE;
	}						
}

void
pref_on_objMountains_toggled                (GtkToggleButton *togglebutton,
					     gpointer         user_data)
{
	if(airUi->pref.set->objMountains) {
		airUi->pref.set->objMountains = TRUE;
	} else {
		airUi->pref.set->objMountains = FALSE;
	}							
}

void
pref_on_probEngine_toggled                  (GtkToggleButton *togglebutton,
					     gpointer         user_data)
{
	if(airUi->pref.set->probEngine) {
		airUi->pref.set->probEngine = TRUE;
	} else {
		airUi->pref.set->probEngine = FALSE;
	}								
}


void
pref_on_probGear_toggled                    (GtkToggleButton *togglebutton,
					     gpointer         user_data)
{
	if(airUi->pref.set->probGear) {
		airUi->pref.set->probGear = TRUE;
	} else {
		airUi->pref.set->probGear = FALSE;
	}									
}


void
pref_on_probTerror_toggled                  (GtkToggleButton *togglebutton,
					     gpointer         user_data)
{
	if(airUi->pref.set->probTerror) {
		airUi->pref.set->probTerror = TRUE;
	} else {
		airUi->pref.set->probTerror = FALSE;
	}										
}


void
pref_on_probPilot_toggled                   (GtkToggleButton *togglebutton,
					     gpointer         user_data)
{
	if(airUi->pref.set->probPilot) {
		airUi->pref.set->probPilot = TRUE;
	} else {
		airUi->pref.set->probPilot = FALSE;
	}											
}


void
pref_on_probAlien_toggled                   (GtkToggleButton *togglebutton,
					     gpointer         user_data)
{
	if(airUi->pref.set->probAlien) {
		airUi->pref.set->probAlien = TRUE;
	} else {
		airUi->pref.set->probAlien = FALSE;
	}
}


void
pref_on_probBirds_toggled                   (GtkToggleButton *togglebutton,
					     gpointer         user_data)
{
	if(airUi->pref.set->probBrids) {
		airUi->pref.set->probBrids = TRUE;
	} else {
		airUi->pref.set->probBrids = FALSE;
	}
}


void
pref_on_butOk_clicked                       (GtkButton       *button,
					     gpointer         user_data)
{
	g_print("Ok button pushed\n");
	airSet = airUi->pref.set;
	gtk_widget_hide(airUi->winPref);	
}


void
pref_on_butCancel_clicked                   (GtkButton       *button,
					     gpointer         user_data)
{
	g_print("Cancel button pushed\n");
	gtk_widget_hide(airUi->winPref);	
}

/* prefWin WM signals */

gint
pref_win_close_btn_clicked(GtkWidget *widget,
			   GdkEvent  *event,
			   gpointer  data)
{
	pref_on_butCancel_clicked(NULL,NULL);
	return(FALSE);
}


/* High scores */
void
hs_on_butOk_clicked                       (GtkButton       *button,
					   gpointer         user_data)
{

}


void
hs_on_butClear_clicked                    (GtkButton       *button,
					   gpointer         user_data)
{

}

/* Signals of the game result board */
void
results_on_okay_clicked                 (GtkButton       *button,
                                        gpointer         user_data)
{
	GtkWidget *win = gtk_widget_get_toplevel(GTK_WIDGET(button));
	gtk_widget_destroy(GTK_WIDGET(win));
}

void
results_on_newgame_clicked              (GtkButton       *button,
                                        gpointer         user_data)
{
	GtkWidget *win = gtk_widget_get_toplevel(GTK_WIDGET(button));
	gameStart();
	gtk_widget_destroy(GTK_WIDGET(win));
}

gint
results_win_close_btn_clicked           (GtkWidget *widget,
					GdkEvent  *event,
					gpointer  data)
{
	gtk_widget_destroy(widget);
	return FALSE;
}


/* ChangeLog
 * $Log: callbacks.c,v $
 * Revision 1.27  2000/04/30 17:21:09  marijn
 * Added a about window.
 *
 * Revision 1.26  2000/04/30 13:55:22  marijn
 * Fixed bug: a plane in the list is selected when it is not on the board.
 *
 * Revision 1.25  2000/04/28 18:56:32  marijn
 * Removed unused callbacks. Progressbar-click now ends a round.
 *
 * Revision 1.24  2000/04/27 20:12:59  marijn
 * fixed bugs: Air plane land; Residue plane images; plane height control
 *
 * Revision 1.23  2000/04/24 23:30:16  marijn
 * Added callbacks for results window. Fixed scoring bug.
 *
 * Revision 1.22  2000/04/24 14:33:32  marijn
 * Fixed ugly segfault bug.
 *
 * Revision 1.21  2000/04/20 22:44:31  marijn
 * Fixed settigns init problem and fixed some small compiler warnings.
 *
 * Revision 1.20  2000/04/20 18:57:07  marijn
 * Scores per plane and maximum are now shown according the game settings.
 *
 * Revision 1.19  2000/04/19 20:41:40  marijn
 * Added the proper callbacks when WM closes windows. Updated preferences
 *
 * Revision 1.18  2000/04/19 05:54:44  marijn
 * Functioning preferences in a new preference window.
 *
 * Revision 1.17  2000/04/16 17:03:46  marijn
 * Removed references to the obsolete support header files.
 *
 * Revision 1.16  2000/04/01 16:55:47  marijn
 * Major source code reordering, added license information.
 *
 * Revision 1.15  2000/03/08 23:34:53  marijn
 * The game now has a proper ending. "End Game" added to the menu.
 *
 * Revision 1.14  2000/03/07 21:04:48  marijn
 * changed all simple on_togg*_toggled callbacks for one on_toggDir_toggled
 *
 * Revision 1.13  2000/03/07 20:22:43  marijn
 * Planes now leave the game when they exit the board. Various minor fixes
 *
 * Revision 1.12  2000/02/21 00:17:02  marijn
 * Changed from GTK to Gnome build. Cleaned up inclusions of header-files.
 *
 * Revision 1.11  2000/01/17 01:39:22  marijn
 * Planes now keep to be the same widgets when they only move.
 * Improved color responce.
 * Added initail support for removing planes when they leave the board.
 *
 * Revision 1.10  1999/12/26 03:21:01  marijn
 * Planes now have xpm images for them.
 * Added comments to much of the global structures.
 *
 * Revision 1.9  1999/11/08 00:23:03  marijn
 * Fixed "height-loosing" bug.. planes seem to move correctly now
 *
 * Revision 1.8  1999/11/06 19:42:40  marijn
 * Buttons are disabled when no plane is selected.
 *
 * Revision 1.7  1999/09/25 18:52:01  marijn
 * nes turn the correct way.
 * clicking on the plane now selects it in the list
 * fixed dubble timing problem
 *
 * Revision 1.6  1999/09/19 18:34:15  marijn
 * Plane selection in the list works.. Information in the list is better.
 * Control buttons now represent plane status.
 *
 * Revision 1.5  1999/09/13 19:43:48  marijn
 * main game round code inserted..
 *
 * Revision 1.4  1999/08/27 13:29:29  marijn
 * planes are get added to the planelist
 *
 */
