/* Data structures for Airtraffic
 * $Id: datastructs.h,v 1.6 2000/04/24 14:51:28 marijn Exp $

 * An air traffic simulation game. 
 * Copyright (C) 2000  Marijn Vriens <marijn@sanity.dhs.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 */

/* Structures */

typedef struct { /* defines differend planetypes */
     	gint      speed;  /* speed of the planetype */
	gint      turn;   /* turning speed of a planetype */
	gboolean  hover;  /* is the plane type capable of hovering */
	gchar     id;     /* identifier of the plane type */
/*     	gchar     name[10]; */
} planeType;

typedef struct { /* non-plane game objects */
	gboolean  land;   /* can there be landing on this object */
	gboolean  fly;    /* are planes allowed to fly over it */
	gint      speed;  /* speed of the object */
	gint      height; /* hight of the object */
} objType;

typedef struct { /* basic vector structure for a object,
		    4th quadrant calculations (0,0 = top left)*/ 
	gint x;  /* horizontal location */
	gint y;  /* vertical location */
	gint z;  /* height of the object */
	gint heading; /* direction of the object */
} vector;

typedef struct {
	gint    roundNr;  /* the number of this round in this game */
	gfloat  progress; /* progress of this round
			   between 0 and 1 */
} airStatus;

typedef struct {
	gint      points;  /* the score of the game */
	gint      planeval;/* the value of one correctly deliverd
			      plane */
	gint      correct; /* number of planes correcty guided */
	gint      nearmiss;/* number of near misses */
} airScore;

typedef struct {
	gint score;  /* The amount of points gathered */
	gint max;    /* The Maximum amount of points one can gather in a game */
	gchar *name; /* The name of the person */
	gint time;   /* Epoch time of when it was finished */
} airHighScore;

typedef struct {
	gint      roundSpeed; /* nr of secs for one round to take */
	gint      gameDuration; /* number of minutes for one game */
	gint      planeNr; /* number of planes */ 
	gint      airportNr; /* number of airports */
	gint      averageFuel;/* The average minutes that a
				 plane has when it enters the game. */
	gint      missDist; /* less then this for a near miss */ 
	gint      crashDist; /* less then this for a crash */
	gint      initMinPlaneDist; /* the least space that the planes 
				      should have when they are created*/ 
	gboolean objJetplane;
	gboolean objPropPlanes;
	gboolean objHelicopters;
	gboolean objNoflyzones;
	gboolean objStormSystem;
	gboolean objPowerCables;
	gboolean objGroundFog;
	gboolean objMountains;

	gboolean probEngine;
	gboolean probGear;
	gboolean probTerror;
	gboolean probPilot;
	gboolean probAlien;
	gboolean probBrids;
	
	airStatus stat;      /* Progres of the current round */
	airScore  score;     /* Scores of the game */
	GList *   highScore; /* Scores of previous games */
	
	objType   otype[2]; /* array with object types */
	planeType ptype[2]; /* array with plane types */
} airSetting;

typedef struct {
	GtkWidget *widget; /* the GTK widget */
	vector     pos;    /* location structure of object */
	objType   *type;   /* pointer to stuct describing the
			      characteristics of the object */
	gchar     *name;   /* pointer to the name of the object */
	gint      id;      /* serial number of the object, NOT FOR INTERNAL ID! */
} airObj;

typedef struct {
	GtkWidget *widget; /* the widget */
	vector    pos;     /* currect pos of the plane */
	vector    cmd;     /* the commands send to the plane */
	planeType *type;   /* charasteristics of the plane */
	airObj    *in;     /* where did the plane come from */
	gint      inHeight;/* at what height does the plane enter */
	airObj    *out;    /* Where should the plane go */
	gint      outHeight;
	gint      inTime;  /* when does the plane enter the game */
	gint      fuel;    /* amount of fuel that the plane is
			      carrying */
} airPlane;

/* Global pointers to data */
airSetting *airSet  ;       /* Pointer to the airsettings */
GList      *airPlanes;      /* List with all active planes in the game */
GList      *airPlanesFinish;/* List with all planes in the game that
			       are finished */
GList      *airObjs;        /* List with all non-plane objects */

/* ChangeLog
 * $Log: datastructs.h,v $
 * Revision 1.6  2000/04/24 14:51:28  marijn
 * Added different airport images.
 *
 * Revision 1.5  2000/04/20 18:57:07  marijn
 * Scores per plane and maximum are now shown according the game settings.
 *
 * Revision 1.4  2000/04/19 05:54:44  marijn
 * Functioning preferences in a new preference window.
 *
 * Revision 1.3  2000/04/16 17:12:31  marijn
 * Added support for saving preferences and highscores to preference files.
 *
 * Revision 1.2  2000/04/02 02:04:24  marijn
 * Added license and cvs log.
 *
 */
