/* Dynamic functions of the user interface. 
 * $Id: ifdynamic.c,v 1.13 2000/04/27 23:25:56 marijn Exp $

 * An air traffic simulation game. 
 * Copyright (C) 2000  Marijn Vriens <marijn@sanity.dhs.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gnome.h>
#include <sys/stat.h>

#include "defaults.h"
#include "datastructs.h"
#include "callbacks.h"
#include "utils.h"
#include "interface.h"

/* prototypes of functions only here */
gchar *
select_plane_image(guint, gchar, gint);

gchar *
select_object_image(guint, gint);

GtkWidget *
create_image_widget(gchar *);

void 
loadFlightList(GtkCList *list, GList *planes) 
{
	airPlane *temp = NULL;
	gchar    *buff[5]; /* *buff[0] = time / fuel
			    * *buff[1] = heading
			    * *buff[2] = the command
			    * *buff[3] = in direction
			    * *buff[4] = out direction
			    */
	gchar    *heading;
	gchar    *test;
	guint    i = 0;
	g_assert(planes != NULL);
	g_assert(list != NULL);

	planes = g_list_first(planes);
	gtk_clist_freeze(list);
	gtk_clist_clear( list );
	do {
		temp = planes->data;
		g_assert(temp != NULL);
		/* free the memory of the old plane rows */
		if(gtk_clist_get_text(list, i, 0, &(test))) {
			int t = 0;
			g_free(test);
			for(t=1; t>5; t++) {
				if(gtk_clist_get_text(list, i, t, &(test))) {
					g_free(test);
				}			 
			}
		}
                /* if the plane is not in the board */
		if( temp->widget == NULL ) {
			buff[0] = secsToMinutes(temp->inTime);  /* time */
			buff[1] = NULL;
			buff[2] = NULL;
			
		} else {
			buff[0] = secsToMinutes(temp->fuel);  /* fuel */
			heading = degsToHeading(temp->pos.heading);
			buff[1] = g_strdup_printf("%s(%d)", heading, temp->pos.z);
			g_free(heading);
			if(temp->cmd.z != -1) {
				heading = degsToHeading(temp->cmd.heading);
				buff[2] = g_strdup_printf("%s(%d)", heading, temp->cmd.z);
				g_free(heading);
			} else {
				buff[2] = NULL;
			}
		}
		if(temp->inHeight == 0) {
			buff[3] = g_strdup_printf ("%s(L)", temp->in->name);
		} else {
			buff[3] = g_strdup_printf ("%s(%d)", temp->in->name, temp->inHeight);
		}
		if(temp->outHeight == 0) {
			buff[4] = g_strdup_printf ("%s(L)", temp->out->name);
		} else {
			buff[4] = g_strdup_printf ("%s(%d)", temp->out->name, temp->outHeight);
		}  

		gtk_clist_append(list, buff);

		gtk_clist_set_row_data( GTK_CLIST(list), i++, temp ); /* add data on the plane to list */

//		g_free(buff);
	} while((planes = g_list_next(planes)) != NULL);
	
	if(airUi->select != NULL) { /* keep the same plane selected during list updates */
		i = gtk_clist_find_row_from_data( GTK_CLIST(list), airUi->select );
		gtk_clist_select_row( GTK_CLIST(list), i, 0);
	}
	gtk_clist_thaw(list);
}

void
clearFlightList(GtkCList *list)
{
	gtk_clist_freeze(list);
	gtk_clist_clear(list);
	gtk_clist_thaw(list);
}

void
game_board_clean(ui* Ui)
{
	Ui->board.main = build_game_board(&Ui->board);
}

void
game_timer_start()
{
	if(airUi->ctrl.timer != 0) { /* if timer was set, remove it */
		gtk_timeout_remove( airUi->ctrl.timer );
		airUi->ctrl.timer = 0;
	}
	/* set the timer for the game */
	airUi->ctrl.timer = gtk_timeout_add( ITERATIONSPEED, game_time_passed, NULL );
}

void
game_timer_stop()
{
	gtk_timeout_remove( airUi->ctrl.timer );
}

void
plane_dir_change(gint direction)
{
	gchar *heading, *new_data;
	gint row;
	g_assert(direction != -1);
	if(airUi->select != NULL) { /* if a plane is selected */
		airUi->select->cmd.heading = direction;
		if(airUi->select->cmd.z == -1) {
			airUi->select->cmd.z = airUi->select->pos.z;
		}
		row = gtk_clist_find_row_from_data( GTK_CLIST(airUi->flist), airUi->select );
		heading = degsToHeading(airUi->select->cmd.heading);
		if(airUi->select->cmd.z == 0) {
			new_data = g_strdup_printf( "%s(%s)", heading, _("L") );
		} else {
			new_data = g_strdup_printf( "%s(%d)", heading, airUi->select->cmd.z);
		}
		gtk_clist_set_text ( GTK_CLIST(airUi->flist), row , 2, new_data);
		g_free(new_data);
		g_free(heading);
	}
}


void  
move_plane(airPlane *plane, gchar status, gboolean changed_image)
{
	gchar *imageName;
	gboolean new = FALSE;

	if(plane->widget != NULL) { /* if the widget exists, hide it */
		gtk_widget_hide( plane->widget );
	}
	if( (changed_image == TRUE) && (plane->widget == NULL) ) {
		gtk_container_remove(GTK_CONTAINER( airUi->board.main ), plane->widget);
	}
	
	if( (plane->widget == NULL) || (changed_image == TRUE) ) {
		new = TRUE;
		imageName = select_plane_image( (guint) plane->type, status, plane->pos.heading);
		plane->widget = create_image_widget(imageName);
		
		gtk_signal_connect (GTK_OBJECT (plane->widget), "clicked",
				    GTK_SIGNAL_FUNC (board_plane_click),
				    plane );
      	} else {
		new = FALSE;
		gtk_widget_ref(plane->widget);
		gtk_container_remove(GTK_CONTAINER( airUi->board.main ), plane->widget);
	}
	
	gtk_table_attach_defaults (GTK_TABLE(airUi->board.main), plane->widget, 
				   plane->pos.x+1, plane->pos.x+2, 
				   plane->pos.y+1, plane->pos.y+2);
//	g_print("plane %x: %d,%d\n", plane, plane->pos.x, plane->pos.y);
	
	if(new == FALSE) {
		gtk_widget_unref( plane->widget );
	}
	gtk_widget_show( plane->widget );
}

void
move_object(airObj *object)
{
	gchar *imageName;

	/* the object has not moved and thus doesn't need to redrawn */
	if( (object->widget != NULL) && (object->type->speed == 0) ) {return;}
	if(object->widget != NULL ) { /* was already on the board */
		gtk_container_remove(GTK_CONTAINER( airUi->board.main ), object->widget);		
	}
	imageName = select_object_image( (guint) object->type, object->id);
	object->widget = create_image_widget(imageName);
	gtk_table_attach_defaults (GTK_TABLE(airUi->board.main), object->widget, 
				   object->pos.x+1, object->pos.x+2, 
				   object->pos.y+1, object->pos.y+2);
	gtk_widget_show( object->widget );
}

void
remove_plane(airPlane *plane)
{
	gint row;
	if(plane->widget != NULL) { /* there's a plane in the field */
		gtk_widget_destroy(plane->widget);
		plane->widget = NULL;
	}
	if(plane == airUi->select) { /* the plane was the selected plane */
		airUi->select = NULL;
	}	
	row = gtk_clist_find_row_from_data( GTK_CLIST( airUi->flist ), plane);
	gtk_clist_remove( GTK_CLIST( airUi->flist ), row);
}

gchar *
select_object_image(guint type, gint id) {
	if( type == (guint) &(airSet->otype[AIRPORT]) ) {
		switch(id) {
		case 0 : return "airport1.png";
		case 1 : return "airport2.png";
		case 2 : return "airport3.png";
		case 3 : return "airport4.png";
		case 4 : return "airport5.png";
		default: g_assert_not_reached();
		}
	} else {
		g_assert_not_reached();
	}
	return NULL;
}

gchar *
select_plane_image(guint type, gchar status, gint heading)
{
	if( type == (guint) &(airSet->ptype[JET]) ) {
		switch(status){
		case IMG_NORMAL:
			switch(heading){
			case 0  : return "jet000N.png";
			case 45 : return "jet045N.png";
			case 90 : return "jet090N.png";
			case 135: return "jet135N.png";
			case 180: return "jet180N.png";
			case 225: return "jet225N.png";
			case 270: return "jet270N.png";
			case 315: return "jet315N.png";
			default : g_assert_not_reached();
			}
		case IMG_CHANGE:
			switch(heading){
			case 0  : return "jet000C.png";
			case 45 : return "jet045C.png";
			case 90 : return "jet090C.png";
			case 135: return "jet135C.png";
			case 180: return "jet180C.png";
			case 225: return "jet225C.png";
			case 270: return "jet270C.png";
			case 315: return "jet315C.png";
			default : g_assert_not_reached();
			}
		case IMG_ACTIVE:
			switch(heading){
			case 0  : return "jet000A.png";
			case 45 : return "jet045A.png";
			case 90 : return "jet090A.png";
			case 135: return "jet135A.png";
			case 180: return "jet180A.png";
			case 225: return "jet225A.png";
			case 270: return "jet270A.png";
			case 315: return "jet315A.png";
			default : g_assert_not_reached();
			}
		default:
			g_assert_not_reached();
		}
	} else {
		g_assert_not_reached();
	}
	return NULL;
}

GtkWidget *
create_image_widget(gchar* imageFileName) 
{
	/* FIXME: Currently using Imlib update to gdkPixbuf when that
	   is in gnome stable release */
	
	GdkPixmap *pixmap_data, *mask;
	GtkWidget *pixmap_widget, *widget;
	GdkImlibImage *im;
	gchar* filename;
	struct stat buf;
	
	g_assert(imageFileName);

	filename = g_strdup_printf("%s/%s", IMAGEDIR, imageFileName);

	if(stat(filename, &buf) == -1) {
		g_print("File %s does not exist\n", filename);
		g_assert_not_reached();
	}
//	g_free(buf);
	
	im = gdk_imlib_load_image(filename); // Load the image into mem.
	if(im == NULL) {
		g_print("LOADING of image %s failed.\n", filename);
		g_assert_not_reached();
	}
	g_free(filename);
	
	gdk_imlib_render(im, im->rgb_width, im->rgb_height);
	pixmap_data = gdk_imlib_move_image(im);
	mask = gdk_imlib_move_mask(im);
	
	pixmap_widget = gtk_pixmap_new(pixmap_data, mask);
	
	gtk_widget_show(pixmap_widget);

	widget = gtk_button_new();

	/* put the bitmap in the button */
	gtk_container_add(GTK_CONTAINER (widget), pixmap_widget);
	/* deref image so when button is destroyed, image is destroyed */
	gdk_pixmap_unref((GdkPixmap *) pixmap_widget);

	return (widget);
}


/* ChangeLog
 * $Log: ifdynamic.c,v $
 * Revision 1.13  2000/04/27 23:25:56  marijn
 * Clean up the game board after a game.
 *
 * Revision 1.12  2000/04/27 20:12:59  marijn
 * fixed bugs: Air plane land; Residue plane images; plane height control
 *
 * Revision 1.11  2000/04/24 14:51:28  marijn
 * Added different airport images.
 *
 * Revision 1.10  2000/04/21 15:31:45  marijn
 * removed hardcode to the image directory. Now it is a compile time option.
 *
 * Revision 1.9  2000/04/16 17:03:45  marijn
 * Removed references to the obsolete support header files.
 *
 * Revision 1.8  2000/04/08 15:03:26  marijn
 * Fixed a bug about where to find the png files.
 *
 * Revision 1.7  2000/04/08 14:07:25  marijn
 * Changed from xpm's in the executable to external png files.
 *
 * Revision 1.6  2000/04/01 16:55:47  marijn
 * Major source code reordering, added license information.
 *
 * Revision 1.5  2000/03/20 01:07:23  marijn
 * Various bugs fixed, plugged all known memory leaks.
 *
 * Revision 1.4  2000/03/08 23:34:53  marijn
 * The game now has a proper ending. "End Game" added to the menu.
 *
 * Revision 1.3  2000/03/07 20:22:43  marijn
 * Planes now leave the game when they exit the board. Various minor fixes
 *
 * Revision 1.2  2000/02/20 23:57:14  marijn
 * Moved build_game_board() to ifstatic.c .
 * AirTraffic is now a Gnome build.
 *
 * Revision 1.1  2000/02/18 20:13:24  marijn
 * Split interface.c into ifdynamic.c and ifstatic.c
 *
 */
