/* Static part of the interface, like window layouts.
 * $Id: ifstatic.c,v 1.14 2000/04/30 17:21:09 marijn Exp $

 * An air traffic simulation game. 
 * Copyright (C) 2000  Marijn Vriens <marijn@sanity.dhs.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gnome.h>

#include "defaults.h"
#include "datastructs.h"
#include "callbacks.h"
#include "interface.h"
#include "utils.h"

ui* 
initUi(void) 
{
	ui *UserInterface = g_new( ui, 1 );
	
	UserInterface->flist = NULL;
	UserInterface->winPref = NULL;
	UserInterface->main  = NULL;
	UserInterface->tips  = NULL;

/* board */	
	UserInterface->board.nw = NULL;
	UserInterface->board.n  = NULL;
	UserInterface->board.ne = NULL;	
	UserInterface->board.w  = NULL;
	UserInterface->board.e  = NULL;
	UserInterface->board.sw = NULL;
	UserInterface->board.s  = NULL;
	UserInterface->board.se = NULL;

/* ctrl */
	UserInterface->ctrl.h      = NULL;
	UserInterface->ctrl.hLabel = NULL;
	UserInterface->ctrl.hAdj   = NULL;
	UserInterface->ctrl.nw     = NULL;
	UserInterface->ctrl.n      = NULL;
	UserInterface->ctrl.ne     = NULL;	
	UserInterface->ctrl.w      = NULL;
	UserInterface->ctrl.c      = NULL;
	UserInterface->ctrl.e      = NULL;
	UserInterface->ctrl.sw     = NULL;
	UserInterface->ctrl.s      = NULL;
	UserInterface->ctrl.se     = NULL;
	UserInterface->ctrl.rl     = NULL;
	UserInterface->ctrl.rr     = NULL;
	UserInterface->ctrl.park   = NULL;
	UserInterface->ctrl.time   = NULL;
	UserInterface->ctrl.timer  = 0;
	
/* preferences */
	UserInterface->pref.pointsPerPlane = 0;
	UserInterface->pref.pointsMax      = 0;
	UserInterface->pref.set            = NULL;

	return UserInterface;
}

GtkWidget *
create_winCtrl (ui *Ui)
{
  GtkWidget *winCtrl;
  GtkWidget *vbox1;
  GtkWidget *menubar;
  GtkWidget *file1;
  GtkWidget *file1_menu;
  GtkAccelGroup *file1_menu_accels;
  GtkWidget *new_game;
  GtkWidget *end_game;
  GtkWidget *preferences;
  GtkWidget *separator1;
  GtkWidget *quit;
  GtkWidget *help1;
  GtkWidget *help1_menu;
  GtkAccelGroup *help1_menu_accels;
  GtkWidget *about;
  GtkWidget *hbox1;
  GtkWidget *vbox4;
  GtkWidget *messageBox;
  GtkWidget *vbox2;
  GtkWidget *vbox3;
  GtkWidget *scrollwin1;
  GtkWidget *time;
  GtkWidget *cur;
  GtkWidget *cmd;
  GtkWidget *in;
  GtkWidget *out;
  GtkWidget *hbox2;
  GtkWidget *vbox8;
  GtkWidget *controltable;
  GSList    *control_group = NULL;
  GtkAccelGroup *accel_group;

  accel_group = gtk_accel_group_new ();

  Ui->tips = gtk_tooltips_new ();
  
  winCtrl = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_object_set_data (GTK_OBJECT (winCtrl), "winCtrl", winCtrl);
  gtk_window_set_title (GTK_WINDOW (winCtrl), _("Airtraffic Controller"));

  vbox1 = gtk_vbox_new (FALSE, 0);
  gtk_widget_ref (vbox1);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "vbox1", vbox1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox1);
  gtk_container_add (GTK_CONTAINER (winCtrl), vbox1);

  menubar = gtk_menu_bar_new ();
  gtk_widget_ref (menubar);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "menubar", menubar,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menubar);
  gtk_box_pack_start (GTK_BOX (vbox1), menubar, FALSE, FALSE, 0);

  file1 = gtk_menu_item_new_with_label (_("File"));
  gtk_widget_ref (file1);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "file1", file1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (file1);
  gtk_container_add (GTK_CONTAINER (menubar), file1);

  file1_menu = gtk_menu_new ();
  gtk_widget_ref (file1_menu);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "file1_menu", file1_menu,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (file1), file1_menu);
  file1_menu_accels = gtk_menu_ensure_uline_accel_group (GTK_MENU (file1_menu));

  new_game = gtk_menu_item_new_with_label (_("New Game"));
  gtk_widget_ref (new_game);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "new_game", new_game,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (new_game);
  gtk_container_add (GTK_CONTAINER (file1_menu), new_game);
  gtk_tooltips_set_tip (Ui->tips, new_game, _("Start a new game"), NULL);
  gtk_widget_add_accelerator (new_game, "activate", accel_group,
                              GDK_n, GDK_MOD1_MASK,
                              GTK_ACCEL_VISIBLE);

  end_game = gtk_menu_item_new_with_label (_("End Game"));
  gtk_widget_ref (end_game);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "end_game", end_game,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (end_game);
  gtk_container_add (GTK_CONTAINER (file1_menu), end_game);
  gtk_tooltips_set_tip (Ui->tips, end_game, _("End the current game"), NULL);
  gtk_widget_add_accelerator (end_game, "activate", accel_group,
                              GDK_e, GDK_MOD1_MASK,
                              GTK_ACCEL_VISIBLE);
  
  preferences = gtk_menu_item_new_with_label (_("Preferences"));
  gtk_widget_ref (preferences);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "preferences", preferences,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (preferences);
  gtk_container_add (GTK_CONTAINER (file1_menu), preferences);
  gtk_tooltips_set_tip (Ui->tips, preferences, _("Setup the game"), NULL);
  gtk_widget_add_accelerator (preferences, "activate", accel_group,
                              GDK_p, GDK_MOD1_MASK,
                              GTK_ACCEL_VISIBLE);

  separator1 = gtk_menu_item_new ();
  gtk_widget_ref (separator1);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "separator1", separator1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (separator1);
  gtk_container_add (GTK_CONTAINER (file1_menu), separator1);
  gtk_widget_set_sensitive (separator1, FALSE);

  quit = gtk_menu_item_new_with_label (_("Quit"));
  gtk_widget_ref (quit);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "quit", quit,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (quit);
  gtk_container_add (GTK_CONTAINER (file1_menu), quit);
  gtk_tooltips_set_tip (Ui->tips, quit, _("Exit the Game"), NULL);
  gtk_widget_add_accelerator (quit, "activate", accel_group,
                              GDK_q, GDK_MOD1_MASK,
                              GTK_ACCEL_VISIBLE);

  help1 = gtk_menu_item_new_with_label (_("Help"));
  gtk_widget_ref (help1);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "help1", help1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (help1);
  gtk_container_add (GTK_CONTAINER (menubar), help1);
  gtk_menu_item_right_justify (GTK_MENU_ITEM (help1));

  help1_menu = gtk_menu_new ();
  gtk_widget_ref (help1_menu);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "help1_menu", help1_menu,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (help1), help1_menu);
  help1_menu_accels = gtk_menu_ensure_uline_accel_group (GTK_MENU (help1_menu));

  about = gtk_menu_item_new_with_label (_("About"));
  gtk_widget_ref (about);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "about", about,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (about);
  gtk_container_add (GTK_CONTAINER (help1_menu), about);
  gtk_tooltips_set_tip (Ui->tips, about, _("Information about AirTraffic"), NULL);

  hbox1 = gtk_hbox_new (FALSE, 0);
  gtk_widget_ref (hbox1);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "hbox1", hbox1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox1);
  gtk_box_pack_start (GTK_BOX (vbox1), hbox1, TRUE, TRUE, 0);

  vbox4 = gtk_vbox_new (FALSE, 0);
  gtk_widget_ref (vbox4);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "vbox4", vbox4,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox4);
  gtk_box_pack_start (GTK_BOX (hbox1), vbox4, TRUE, TRUE, 0);


  /* the game board */
  Ui->board.main = build_game_board(&Ui->board);
  gtk_box_pack_start (GTK_BOX (vbox4), Ui->board.main, TRUE, TRUE, 0);

  messageBox = gtk_statusbar_new ();
  gtk_widget_ref (messageBox);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "messageBox", messageBox,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (messageBox);
  gtk_box_pack_start (GTK_BOX (vbox4), messageBox, TRUE, TRUE, 0);

  vbox2 = gtk_vbox_new (FALSE, 0);
  gtk_widget_ref (vbox2);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "vbox2", vbox2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox2);
  gtk_box_pack_start (GTK_BOX (hbox1), vbox2, TRUE, TRUE, 0);

  vbox3 = gtk_vbox_new (FALSE, 0);
  gtk_widget_ref (vbox3);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "vbox3", vbox3,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox3);
  gtk_box_pack_start (GTK_BOX (vbox2), vbox3, TRUE, TRUE, 0);

  scrollwin1 = gtk_scrolled_window_new (NULL, NULL);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrollwin1),
                                  GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
  gtk_box_pack_start (GTK_BOX (vbox3), scrollwin1, TRUE, TRUE, 0);
  gtk_widget_show (scrollwin1);

  Ui->flist = gtk_clist_new (5);
  gtk_widget_ref (Ui->flist);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "flightlist", Ui->flist,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_container_add(GTK_CONTAINER(scrollwin1), Ui->flist);
  gtk_widget_show (Ui->flist);
  
  gtk_clist_set_column_width (GTK_CLIST (Ui->flist), 0, 50);
  gtk_clist_set_column_width (GTK_CLIST (Ui->flist), 1, 50);
  gtk_clist_set_column_width (GTK_CLIST (Ui->flist), 2, 50);
  gtk_clist_set_column_width (GTK_CLIST (Ui->flist), 3, 50);
  gtk_clist_set_column_width (GTK_CLIST (Ui->flist), 4, 50);
  gtk_clist_column_titles_show (GTK_CLIST (Ui->flist));
  gtk_clist_set_selection_mode(GTK_CLIST (Ui->flist), GTK_SELECTION_SINGLE);
  gtk_clist_set_shadow_type (GTK_CLIST (Ui->flist), GTK_SHADOW_ETCHED_IN);

  time = gtk_label_new (_("Time"));
  gtk_widget_ref (time);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "Time", time,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (time);
  gtk_clist_set_column_widget (GTK_CLIST (Ui->flist), 0, time);


  cur = gtk_label_new (_("Cur"));
  gtk_widget_ref (cur);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "cur", cur,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (cur);
  gtk_clist_set_column_widget (GTK_CLIST (Ui->flist), 1, cur);


  cmd = gtk_label_new (_("Cmd"));
  gtk_widget_ref (cmd);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "cmd", cmd,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (cmd);
  gtk_clist_set_column_widget (GTK_CLIST (Ui->flist), 2, cmd);


  in = gtk_label_new (_("In"));
  gtk_widget_ref (in);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "in", in,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (in);
  gtk_clist_set_column_widget (GTK_CLIST (Ui->flist), 3, in);


  out = gtk_label_new (_("Out"));
  gtk_widget_ref (out);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "out", out,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (out);
  gtk_clist_set_column_widget (GTK_CLIST (Ui->flist), 4, out);

  hbox2 = gtk_hbox_new (FALSE, 0);
  gtk_widget_ref (hbox2);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "hbox2", hbox2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox2);
  gtk_box_pack_start (GTK_BOX (vbox3), hbox2, TRUE, TRUE, 0);

  vbox8 = gtk_vbox_new (FALSE, 0);
  gtk_widget_ref (vbox8);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "vbox8", vbox8,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox8);
  gtk_box_pack_start (GTK_BOX (hbox2), vbox8, FALSE, FALSE, 0);

  Ui->ctrl.hLabel = gtk_label_new (_("10"));
  gtk_widget_ref (Ui->ctrl.hLabel);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "labHight", Ui->ctrl.hLabel,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (Ui->ctrl.hLabel);
  gtk_box_pack_start (GTK_BOX (vbox8), Ui->ctrl.hLabel, FALSE, FALSE, 0);

  Ui->ctrl.hAdj = gtk_adjustment_new (0, 0, AIR_BOARD_Z, 1, 1, 1);
  Ui->ctrl.h = gtk_vscale_new (GTK_ADJUSTMENT (Ui->ctrl.hAdj));
  gtk_widget_ref (Ui->ctrl.h);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "scaleHeight", Ui->ctrl.h,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (Ui->ctrl.h);
  gtk_box_pack_start (GTK_BOX (vbox8), Ui->ctrl.h, TRUE, TRUE, 0);
  gtk_scale_set_draw_value (GTK_SCALE (Ui->ctrl.h), FALSE);

  controltable = gtk_table_new (4, 3, TRUE);
  gtk_widget_ref (controltable);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "controltable", controltable,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (controltable);
  gtk_box_pack_start (GTK_BOX (hbox2), controltable, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (controltable), 3);
  gtk_table_set_row_spacings (GTK_TABLE (controltable), 2);
  gtk_table_set_col_spacings (GTK_TABLE (controltable), 2);

  Ui->ctrl.rl = gtk_radio_button_new_with_label (control_group,  _("Rotate Left"));
  control_group = gtk_radio_button_group (GTK_RADIO_BUTTON (Ui->ctrl.rl));
  gtk_widget_ref (Ui->ctrl.rl);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "toggRL", Ui->ctrl.rl,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_table_attach (GTK_TABLE (controltable), Ui->ctrl.rl, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL), 0, 0);
  gtk_tooltips_set_tip (Ui->tips, Ui->ctrl.rl, _("Fly lefthand circle"), NULL);
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (Ui->ctrl.rl), FALSE);



  Ui->ctrl.sw = gtk_radio_button_new_with_label (control_group, _("South West"));
  control_group = gtk_radio_button_group (GTK_RADIO_BUTTON (Ui->ctrl.sw));
  gtk_widget_ref (Ui->ctrl.sw);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "toggSW", Ui->ctrl.sw,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (Ui->ctrl.sw);
  gtk_table_attach (GTK_TABLE (controltable), Ui->ctrl.sw, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL), 0, 0);
  gtk_tooltips_set_tip (Ui->tips, Ui->ctrl.sw, _("Turn plane south east"), NULL);
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (Ui->ctrl.sw), FALSE);



  Ui->ctrl.w = gtk_radio_button_new_with_label (control_group, _("West"));
  control_group = gtk_radio_button_group (GTK_RADIO_BUTTON (Ui->ctrl.w));
  gtk_widget_ref (Ui->ctrl.w);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "toggW", Ui->ctrl.w,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (Ui->ctrl.w);
  gtk_table_attach (GTK_TABLE (controltable), Ui->ctrl.w, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL), 0, 0);
  gtk_tooltips_set_tip (Ui->tips, Ui->ctrl.w, _("Turn plane west"), NULL);
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (Ui->ctrl.w), FALSE);



  Ui->ctrl.nw = gtk_radio_button_new_with_label (control_group, _("North West"));
  control_group = gtk_radio_button_group (GTK_RADIO_BUTTON (Ui->ctrl.nw));
  gtk_widget_ref (Ui->ctrl.nw);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "toggNW", Ui->ctrl.nw,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (Ui->ctrl.nw);
  gtk_table_attach (GTK_TABLE (controltable), Ui->ctrl.nw, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL), 0, 0);
  gtk_tooltips_set_tip (Ui->tips, Ui->ctrl.nw, _("Turn Plane North West"), NULL);
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (Ui->ctrl.nw), FALSE);



  Ui->ctrl.n = gtk_radio_button_new_with_label (control_group, _("North"));
  control_group = gtk_radio_button_group (GTK_RADIO_BUTTON (Ui->ctrl.n));
  gtk_widget_ref (Ui->ctrl.n);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "toggN", Ui->ctrl.n,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (Ui->ctrl.n);
  gtk_table_attach (GTK_TABLE (controltable), Ui->ctrl.n, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL), 0, 0);
  gtk_tooltips_set_tip (Ui->tips, Ui->ctrl.n, _("Turn Plane North"), NULL);
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (Ui->ctrl.n), FALSE);



  Ui->ctrl.c = gtk_radio_button_new_with_label (control_group, _("Center"));
  control_group = gtk_radio_button_group (GTK_RADIO_BUTTON (Ui->ctrl.c));
  gtk_widget_ref (Ui->ctrl.c);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "toggC", Ui->ctrl.c,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_table_attach (GTK_TABLE (controltable), Ui->ctrl.c, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL), 0, 0);
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (Ui->ctrl.c), FALSE);


  Ui->ctrl.s = gtk_radio_button_new_with_label (control_group, _("South"));
  control_group = gtk_radio_button_group (GTK_RADIO_BUTTON (Ui->ctrl.s));
  gtk_widget_ref (Ui->ctrl.s);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "toggS", Ui->ctrl.s,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (Ui->ctrl.s);
  gtk_table_attach (GTK_TABLE (controltable), Ui->ctrl.s, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL), 0, 0);
  gtk_tooltips_set_tip (Ui->tips, Ui->ctrl.s, _("Turn plane south"), NULL);
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (Ui->ctrl.s), FALSE);


  Ui->ctrl.ne = gtk_radio_button_new_with_label (control_group, _("North East"));
  control_group = gtk_radio_button_group (GTK_RADIO_BUTTON (Ui->ctrl.ne));
  gtk_widget_ref (Ui->ctrl.ne);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "toggNE", Ui->ctrl.ne,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (Ui->ctrl.ne);
  gtk_table_attach (GTK_TABLE (controltable), Ui->ctrl.ne, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL), 0, 0);
  gtk_tooltips_set_tip (Ui->tips, Ui->ctrl.ne, _("Turn Plane North East"), NULL);
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (Ui->ctrl.ne), FALSE);



  Ui->ctrl.e = gtk_radio_button_new_with_label (control_group, _("East"));
  control_group = gtk_radio_button_group (GTK_RADIO_BUTTON (Ui->ctrl.e));
  gtk_widget_ref (Ui->ctrl.e);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "toggE", Ui->ctrl.e,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (Ui->ctrl.e);
  gtk_table_attach (GTK_TABLE (controltable), Ui->ctrl.e, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL), 0, 0);
  gtk_tooltips_set_tip (Ui->tips, Ui->ctrl.e, _("Turn plane east"), NULL);
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (Ui->ctrl.e), FALSE);



  Ui->ctrl.se = gtk_radio_button_new_with_label (control_group, _("South East"));
  control_group = gtk_radio_button_group (GTK_RADIO_BUTTON (Ui->ctrl.se));
  gtk_widget_ref (Ui->ctrl.se);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "toggSE", Ui->ctrl.se,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (Ui->ctrl.se);
  gtk_table_attach (GTK_TABLE (controltable), Ui->ctrl.se, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL), 0, 0);
  gtk_tooltips_set_tip (Ui->tips, Ui->ctrl.se, _("Turn plane south east"), NULL);
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (Ui->ctrl.se), FALSE);



  Ui->ctrl.rr = gtk_radio_button_new_with_label (control_group, _("Rotate Right"));
  control_group = gtk_radio_button_group (GTK_RADIO_BUTTON (Ui->ctrl.rr));
  gtk_widget_ref (Ui->ctrl.rr);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "toggRR", Ui->ctrl.rr,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_table_attach (GTK_TABLE (controltable), Ui->ctrl.rr, 2, 3, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL), 0, 0);
  gtk_tooltips_set_tip (Ui->tips, Ui->ctrl.rr, _("Fly right circle"), NULL);
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (Ui->ctrl.rr), FALSE);



  Ui->ctrl.park = gtk_radio_button_new_with_label (control_group, _("Fly Park Pattern"));
  control_group = gtk_radio_button_group (GTK_RADIO_BUTTON (Ui->ctrl.park));
  gtk_widget_ref (Ui->ctrl.park);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "toggPark", Ui->ctrl.park,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_table_attach (GTK_TABLE (controltable), Ui->ctrl.park, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL), 0, 0);
  gtk_tooltips_set_tip (Ui->tips, Ui->ctrl.park, _("fly parking pattern"), NULL);
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (Ui->ctrl.park), FALSE);



  Ui->ctrl.time = gtk_progress_bar_new ();
  gtk_widget_set_events (Ui->ctrl.time, GDK_BUTTON_PRESS_MASK);
  gtk_widget_ref (Ui->ctrl.time);
  gtk_object_set_data_full (GTK_OBJECT (winCtrl), "roundtime", Ui->ctrl.time,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (Ui->ctrl.time);
  gtk_box_pack_start (GTK_BOX (vbox3), Ui->ctrl.time, FALSE, FALSE, 0);
  gtk_progress_set_show_text (GTK_PROGRESS (Ui->ctrl.time), TRUE);

  gtk_signal_connect (GTK_OBJECT (menubar), "selection_done",
                      GTK_SIGNAL_FUNC (on_menubar1_selection_done),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (new_game), "activate",
                      GTK_SIGNAL_FUNC (on_new_game_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (end_game), "activate",
                      GTK_SIGNAL_FUNC (on_end_game_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (preferences), "activate",
                      GTK_SIGNAL_FUNC (on_preferences_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (quit), "activate",
                      GTK_SIGNAL_FUNC (on_quit_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (help1), "activate",
                      GTK_SIGNAL_FUNC (on_help1_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (about), "activate",
                      GTK_SIGNAL_FUNC (on_about_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (Ui->flist), "select_row",
                      GTK_SIGNAL_FUNC (on_flightlist_select_row),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (Ui->flist), "unselect_row",
                      GTK_SIGNAL_FUNC (on_flightlist_unselect_row),
                      NULL);

/* plane height selector */
  gtk_signal_connect (GTK_OBJECT (Ui->ctrl.hAdj), "value_changed",
                      GTK_SIGNAL_FUNC (on_hscale_value_change),
                      NULL);

/* plane control buttons */
  gtk_widget_set_sensitive( GTK_WIDGET(Ui->ctrl.n),  FALSE);
  gtk_widget_set_sensitive( GTK_WIDGET(Ui->ctrl.ne), FALSE);
  gtk_widget_set_sensitive( GTK_WIDGET(Ui->ctrl.e),  FALSE);
  gtk_widget_set_sensitive( GTK_WIDGET(Ui->ctrl.se), FALSE);
  gtk_widget_set_sensitive( GTK_WIDGET(Ui->ctrl.s),  FALSE);
  gtk_widget_set_sensitive( GTK_WIDGET(Ui->ctrl.sw), FALSE);
  gtk_widget_set_sensitive( GTK_WIDGET(Ui->ctrl.w),  FALSE);
  gtk_widget_set_sensitive( GTK_WIDGET(Ui->ctrl.nw), FALSE);
  gtk_widget_set_sensitive( GTK_WIDGET(Ui->ctrl.h),  FALSE);
  
  gtk_signal_connect (GTK_OBJECT (Ui->ctrl.n), "toggled",
                      GTK_SIGNAL_FUNC (on_toggDir_toggled),
                      GINT_TO_POINTER(0));
  gtk_signal_connect (GTK_OBJECT (Ui->ctrl.ne), "toggled",
                      GTK_SIGNAL_FUNC (on_toggDir_toggled),
                      GINT_TO_POINTER(45));
  gtk_signal_connect (GTK_OBJECT (Ui->ctrl.e), "toggled",
                      GTK_SIGNAL_FUNC (on_toggDir_toggled),
                      GINT_TO_POINTER(90));
  gtk_signal_connect (GTK_OBJECT (Ui->ctrl.se), "toggled",
                      GTK_SIGNAL_FUNC (on_toggDir_toggled),
                      GINT_TO_POINTER(135));
  gtk_signal_connect (GTK_OBJECT (Ui->ctrl.s), "toggled",
                      GTK_SIGNAL_FUNC (on_toggDir_toggled),
                      GINT_TO_POINTER(180));
  gtk_signal_connect (GTK_OBJECT (Ui->ctrl.sw), "toggled",
                      GTK_SIGNAL_FUNC (on_toggDir_toggled),
                      GINT_TO_POINTER(225));
  gtk_signal_connect (GTK_OBJECT (Ui->ctrl.w), "toggled",
                      GTK_SIGNAL_FUNC (on_toggDir_toggled),
                      GINT_TO_POINTER(270));
  gtk_signal_connect (GTK_OBJECT (Ui->ctrl.nw), "toggled",
                      GTK_SIGNAL_FUNC (on_toggDir_toggled),
                      GINT_TO_POINTER(315));

  gtk_signal_connect (GTK_OBJECT (Ui->ctrl.c), "toggled",
		      GTK_SIGNAL_FUNC (on_toggC_toggled),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (Ui->ctrl.rl), "toggled",
                      GTK_SIGNAL_FUNC (on_toggRL_toggled),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (Ui->ctrl.rr), "toggled",
                      GTK_SIGNAL_FUNC (on_toggRR_toggled),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (Ui->ctrl.park), "toggled",
                      GTK_SIGNAL_FUNC (on_toggPark_toggled),
                      NULL);

/* round time */
  gtk_signal_connect (GTK_OBJECT (Ui->ctrl.time), "button_press_event",
                      GTK_SIGNAL_FUNC (on_roundtime_button_release_event),
                      NULL);
  
/* window close */
  gtk_signal_connect (GTK_OBJECT (winCtrl), "delete_event",
		      GTK_SIGNAL_FUNC (cntl_win_close_btn_clicked), NULL);

  gtk_object_set_data (GTK_OBJECT (winCtrl), "tooltips", Ui->tips);

  gtk_window_add_accel_group (GTK_WINDOW (winCtrl), accel_group);

  Ui->main = winCtrl;
  return winCtrl;
}

GtkWidget * 
create_winPref (ui *Ui, airSetting *set)
{
	
	GtkWidget *winPreferences;
	GtkWidget *vbox3;
	GtkWidget *notebook1;
	GtkWidget *table2;
	GtkWidget *label13;
	GtkWidget *label14;
	GtkWidget *label15;
	GtkWidget *label16;
	GtkWidget *scaleNrOfPlanes;
	GtkWidget *scaleNrOfAirport;
	GtkWidget *scaleRoundSpeed;
	GtkWidget *scaleGameDuration;
	
	GtkObject *adjNrOfPlanes;
	GtkObject *adjNrOfAirport;
	GtkObject *adjRoundSpeed;
	GtkObject *adjGameDuration;
	GtkObject *adjNearMiss;
	GtkObject *adjAverageFuel;
	GtkObject *adjReliability;
	
	GtkWidget *objJetplane;
	GtkWidget *objPropPlanes;
	GtkWidget *objHelicopters;
	GtkWidget *objNoflyzones;
	GtkWidget *objStormSystem;
	GtkWidget *objPowerCables;
	GtkWidget *objGroundFog;
	GtkWidget *objMountains;
	GtkWidget *probEngine;
	GtkWidget *probGear;
	GtkWidget *probTerror;
	GtkWidget *probPilot;
	GtkWidget *probAlien;
	GtkWidget *probBirds;
	
	GtkWidget *label17;
	GtkWidget *scaleNearMiss;
	GtkWidget *label18;
	GtkWidget *scaleAverageFuel;
	GtkWidget *label6;
	GtkWidget *table3;
	GtkWidget *vseparator1;
	GtkWidget *label7;
	GtkWidget *vbox2;
	GtkWidget *hbox1;
	GtkWidget *label19;
	GtkWidget *scaleReliability;
	GtkWidget *hseparator1;
	GtkWidget *table6;
	GtkWidget *vseparator2;
	GtkWidget *label8;
	GtkWidget *table1;
	GtkWidget *label9;
	GtkWidget *label10;
	GtkWidget *hseparator2;
	GtkWidget *hbox2;
	GtkWidget *butOk;
	GtkWidget *butCancel;

	gchar buff[12];
	
  winPreferences = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_window_set_modal(GTK_WINDOW (winPreferences), TRUE);
  gtk_object_set_data (GTK_OBJECT (winPreferences), "winPreferences", winPreferences);
  gtk_window_set_title (GTK_WINDOW (winPreferences), _("Preferences"));

  vbox3 = gtk_vbox_new (FALSE, 0);
  gtk_widget_ref (vbox3);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "vbox3", vbox3,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox3);
  gtk_container_add (GTK_CONTAINER (winPreferences), vbox3);

  notebook1 = gtk_notebook_new ();
  gtk_widget_ref (notebook1);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "notebook1", notebook1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (notebook1);
  gtk_box_pack_start (GTK_BOX (vbox3), notebook1, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (notebook1), 7);

  table2 = gtk_table_new (6, 2, FALSE);
  gtk_widget_ref (table2);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "table2", table2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table2);
  gtk_container_add (GTK_CONTAINER (notebook1), table2);
  gtk_container_set_border_width (GTK_CONTAINER (table2), 4);
  gtk_table_set_row_spacings (GTK_TABLE (table2), 4);
  gtk_table_set_col_spacings (GTK_TABLE (table2), 4);

  label13 = gtk_label_new (_("Number of planes"));
  gtk_widget_ref (label13);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "label13", label13,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label13);
  gtk_table_attach (GTK_TABLE (table2), label13, 0, 1, 0, 1,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);

  label14 = gtk_label_new (_("Number of Airport"));
  gtk_widget_ref (label14);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "label14", label14,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label14);
  gtk_table_attach (GTK_TABLE (table2), label14, 0, 1, 1, 2,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  
  label15 = gtk_label_new (_("Round speed"));
  gtk_widget_ref (label15);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "label15", label15,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label15);
  gtk_table_attach (GTK_TABLE (table2), label15, 0, 1, 2, 3,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);

  label16 = gtk_label_new (_("Game duration"));
  gtk_widget_ref (label16);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "label16", label16,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label16);
  gtk_table_attach (GTK_TABLE (table2), label16, 0, 1, 3, 4,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);

  adjNrOfPlanes = gtk_adjustment_new (set->planeNr, AIR_NROFAIRCRAFT_MIN, AIR_NROFAIRCRAFT_MAX, 1, 5, 5);
  scaleNrOfPlanes = gtk_hscale_new (GTK_ADJUSTMENT (adjNrOfPlanes));
  gtk_widget_ref (scaleNrOfPlanes);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "scaleNrOfPlanes", scaleNrOfPlanes,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_scale_set_digits(GTK_SCALE(scaleNrOfPlanes), 0);
  gtk_widget_show (scaleNrOfPlanes);
  gtk_table_attach (GTK_TABLE (table2), scaleNrOfPlanes, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_scale_set_value_pos (GTK_SCALE (scaleNrOfPlanes), GTK_POS_LEFT);
  gtk_tooltips_set_tip (Ui->tips, scaleNrOfPlanes, _("The number of planes in the game"), NULL);

  adjNrOfAirport = gtk_adjustment_new (set->airportNr, AIR_NROFAIRPORT_MIN, AIR_NROFAIRPORT_MAX, 1, 1, 1);
  scaleNrOfAirport = gtk_hscale_new (GTK_ADJUSTMENT (adjNrOfAirport));
  gtk_widget_ref (scaleNrOfAirport);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "scaleNrOfAirport", scaleNrOfAirport,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_scale_set_digits(GTK_SCALE(scaleNrOfAirport), 0);
  gtk_widget_show (scaleNrOfAirport);
  gtk_table_attach (GTK_TABLE (table2), scaleNrOfAirport, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_scale_set_value_pos (GTK_SCALE (scaleNrOfAirport), GTK_POS_LEFT);
  gtk_tooltips_set_tip (Ui->tips, scaleNrOfPlanes, _("The number of airport on the board"), NULL);

  adjRoundSpeed  = gtk_adjustment_new (set->roundSpeed, AIR_ROUNDSPEED_MIN, AIR_ROUNDSPEED_MAX, 1, 5, 5);
  scaleRoundSpeed = gtk_hscale_new (GTK_ADJUSTMENT (adjRoundSpeed));
  gtk_widget_ref (scaleRoundSpeed);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "scaleRoundSpeed", scaleRoundSpeed,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_scale_set_digits(GTK_SCALE(scaleRoundSpeed), 0);
  gtk_widget_show (scaleRoundSpeed);
  gtk_table_attach (GTK_TABLE (table2), scaleRoundSpeed, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_scale_set_value_pos (GTK_SCALE (scaleRoundSpeed), GTK_POS_LEFT);
  gtk_tooltips_set_tip (Ui->tips, scaleRoundSpeed, _("The number of seconds one turn takes"), NULL);

  adjGameDuration = gtk_adjustment_new (set->gameDuration, AIR_GAMEDURATION_MIN, AIR_GAMEDURATION_MAX, 0, 0, 0);
  scaleGameDuration = gtk_hscale_new (GTK_ADJUSTMENT (adjGameDuration));
  gtk_widget_ref (scaleGameDuration);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "scaleGameDuration", scaleGameDuration,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_scale_set_digits(GTK_SCALE(scaleGameDuration), 0);
  gtk_widget_show (scaleGameDuration);
  gtk_table_attach (GTK_TABLE (table2), scaleGameDuration, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_scale_set_value_pos (GTK_SCALE (scaleGameDuration), GTK_POS_LEFT);
    gtk_tooltips_set_tip (Ui->tips, scaleGameDuration, _("The number of minutes in which all the planes will come in"), NULL);

  label17 = gtk_label_new (_("Near-miss distance"));
  gtk_widget_ref (label17);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "label17", label17,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label17);
  gtk_table_attach (GTK_TABLE (table2), label17, 0, 1, 5, 6,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  
  adjNearMiss = gtk_adjustment_new (set->missDist, AIR_MISSDIST_MIN, AIR_MISSDIST_MAX, 1, 1, 1);
  scaleNearMiss = gtk_hscale_new (GTK_ADJUSTMENT (adjNearMiss));
  gtk_widget_ref (scaleNearMiss);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "scaleNearMiss", scaleNearMiss,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_scale_set_digits(GTK_SCALE(scaleNearMiss), 0);
  gtk_widget_show (scaleNearMiss);
  gtk_table_attach (GTK_TABLE (table2), scaleNearMiss, 1, 2, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_scale_set_value_pos (GTK_SCALE (scaleNearMiss), GTK_POS_LEFT);
  gtk_tooltips_set_tip (Ui->tips, scaleNearMiss, _("The distance that gives near miss warnings."), NULL);
  
  label18 = gtk_label_new (_("Average Fuel minutes"));
  gtk_widget_ref (label18);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "label18", label18,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label18);
  gtk_table_attach (GTK_TABLE (table2), label18, 0, 1, 4, 5,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);

  adjAverageFuel = gtk_adjustment_new (0, 0, 0, 0, 0, 0);
  scaleAverageFuel = gtk_hscale_new (GTK_ADJUSTMENT (adjAverageFuel));
  gtk_widget_ref (scaleAverageFuel);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "scaleAverageFuel", scaleAverageFuel,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scaleAverageFuel);
  gtk_scale_set_digits(GTK_SCALE(scaleAverageFuel), 0);
  gtk_table_attach (GTK_TABLE (table2), scaleAverageFuel, 1, 2, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_scale_set_value_pos (GTK_SCALE (scaleAverageFuel), GTK_POS_LEFT);
  gtk_widget_set_sensitive (scaleAverageFuel, FALSE);
  gtk_tooltips_set_tip (Ui->tips, scaleAverageFuel, _("The average minutes of fuel planes have left when they enter the game"), NULL);
  
  label6 = gtk_label_new (_("Game"));
  gtk_widget_ref (label6);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "label6", label6,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label6);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook1), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook1), 0), label6);

  table3 = gtk_table_new (5, 3, FALSE);
  gtk_widget_ref (table3);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "table3", table3,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table3);
  gtk_container_add (GTK_CONTAINER (notebook1), table3);
  gtk_widget_set_sensitive (table3, FALSE);

  objJetplane = gtk_check_button_new_with_label (_("Jet planes"));
  gtk_widget_ref (objJetplane);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "objJetplane", objJetplane,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (objJetplane);
  gtk_table_attach (GTK_TABLE (table3), objJetplane, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_sensitive (objJetplane, FALSE);
  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (objJetplane), TRUE);
  gtk_tooltips_set_tip (Ui->tips, objJetplane, _("The games contain jet planes"), NULL);
  
  objPropPlanes = gtk_check_button_new_with_label (_("Propelor planes"));
  gtk_widget_ref (objPropPlanes);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "objPropPlanes", objPropPlanes,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (objPropPlanes);
  gtk_table_attach (GTK_TABLE (table3), objPropPlanes, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_sensitive (objPropPlanes, FALSE);
  gtk_tooltips_set_tip (Ui->tips, objPropPlanes, _("The games contain propelor planes"), NULL);

  objHelicopters = gtk_check_button_new_with_label (_("Helicopters"));
  gtk_widget_ref (objHelicopters);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "objHelicopters", objHelicopters,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (objHelicopters);
  gtk_table_attach (GTK_TABLE (table3), objHelicopters, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_sensitive (objHelicopters, FALSE);
  gtk_tooltips_set_tip (Ui->tips, objHelicopters, _("The games contain Helicopters"), NULL);

  objNoflyzones = gtk_check_button_new_with_label (_("No-Fly zones"));
  gtk_widget_ref (objNoflyzones);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "objNoflyzones", objNoflyzones,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (objNoflyzones);
  gtk_table_attach (GTK_TABLE (table3), objNoflyzones, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_sensitive (objNoflyzones, FALSE);
  gtk_tooltips_set_tip (Ui->tips, objNoflyzones, _("The games contains zones where planes are not allowed to fly over"), NULL);

  vseparator1 = gtk_vseparator_new ();
  gtk_widget_ref (vseparator1);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "vseparator1", vseparator1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vseparator1);
  gtk_table_attach (GTK_TABLE (table3), vseparator1, 1, 2, 0, 5,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  objStormSystem = gtk_check_button_new_with_label (_("Storm systems"));
  gtk_widget_ref (objStormSystem);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "objStormSystem", objStormSystem,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (objStormSystem);
  gtk_table_attach (GTK_TABLE (table3), objStormSystem, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_sensitive (objStormSystem, FALSE);
  gtk_tooltips_set_tip (Ui->tips, objStormSystem, _("Storm systems are something planes have to avoid flying into"), NULL);

  objPowerCables = gtk_check_button_new_with_label (_("Power cables"));
  gtk_widget_ref (objPowerCables);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "objPowerCables", objPowerCables,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (objPowerCables);
  gtk_table_attach (GTK_TABLE (table3), objPowerCables, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_sensitive (objPowerCables, FALSE);
  gtk_tooltips_set_tip (Ui->tips, objPowerCables, _("The game board has powercables"), NULL);

  objGroundFog = gtk_check_button_new_with_label (_("Ground fog"));
  gtk_widget_ref (objGroundFog);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "objGroundFog", objGroundFog,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (objGroundFog);
  gtk_table_attach (GTK_TABLE (table3), objGroundFog, 2, 3, 4, 5,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_sensitive (objGroundFog, FALSE);
  gtk_tooltips_set_tip (Ui->tips, objGroundFog, _("Fog can close airports temporarily."), NULL);

  objMountains = gtk_check_button_new_with_label (_("Mountains"));
  gtk_widget_ref (objMountains);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "objMountains", objMountains,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (objMountains);
  gtk_table_attach (GTK_TABLE (table3), objMountains, 2, 3, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_sensitive (objMountains, FALSE);
  gtk_tooltips_set_tip (Ui->tips, objMountains, _("The game board contains contains mountains."), NULL);

  label7 = gtk_label_new (_("Objects"));
  gtk_widget_ref (label7);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "label7", label7,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label7);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook1), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook1), 1), label7);

  vbox2 = gtk_vbox_new (FALSE, 0);
  gtk_widget_ref (vbox2);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "vbox2", vbox2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox2);
  gtk_container_add (GTK_CONTAINER (notebook1), vbox2);

  hbox1 = gtk_hbox_new (FALSE, 7);
  gtk_widget_ref (hbox1);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "hbox1", hbox1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox1);
  gtk_box_pack_start (GTK_BOX (vbox2), hbox1, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbox1), 2);

  label19 = gtk_label_new (_("Plane reliability"));
  gtk_widget_ref (label19);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "label19", label19,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label19);
  gtk_box_pack_start (GTK_BOX (hbox1), label19, FALSE, FALSE, 0);

  adjReliability = gtk_adjustment_new (0, 0, 0, 0, 0, 0);
  scaleReliability = gtk_hscale_new (GTK_ADJUSTMENT (adjReliability));
  gtk_widget_ref (scaleReliability);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "scaleReliability", scaleReliability,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_scale_set_digits(GTK_SCALE(scaleReliability), 0);
  gtk_widget_show (scaleReliability);
  gtk_box_pack_start (GTK_BOX (hbox1), scaleReliability, TRUE, TRUE, 0);
  gtk_widget_set_sensitive (scaleReliability, FALSE);
  gtk_scale_set_value_pos (GTK_SCALE (scaleReliability), GTK_POS_LEFT);
  gtk_range_set_update_policy (GTK_RANGE (scaleReliability), GTK_UPDATE_DELAYED);
  gtk_tooltips_set_tip (Ui->tips, scaleReliability, _("How prone are the planes to problems of all sorts"), NULL);

  hseparator1 = gtk_hseparator_new ();
  gtk_widget_ref (hseparator1);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "hseparator1", hseparator1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hseparator1);
  gtk_box_pack_start (GTK_BOX (vbox2), hseparator1, FALSE, FALSE, 0);

  table6 = gtk_table_new (3, 3, FALSE);
  gtk_widget_ref (table6);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "table6", table6,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table6);
  gtk_box_pack_start (GTK_BOX (vbox2), table6, TRUE, TRUE, 0);

  vseparator2 = gtk_vseparator_new ();
  gtk_widget_ref (vseparator2);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "vseparator2", vseparator2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vseparator2);
  gtk_table_attach (GTK_TABLE (table6), vseparator2, 1, 2, 0, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  probEngine = gtk_check_button_new_with_label (_("Plane engines"));
  gtk_widget_ref (probEngine);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "probEngine", probEngine,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (probEngine);
  gtk_table_attach (GTK_TABLE (table6), probEngine, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_sensitive (probEngine, FALSE);
  gtk_tooltips_set_tip (Ui->tips, probEngine, _("Planes can have engine problems"), NULL);

  probGear = gtk_check_button_new_with_label (_("Landing gear"));
  gtk_widget_ref (probGear);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "probGear", probGear,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (probGear);
  gtk_table_attach (GTK_TABLE (table6), probGear, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_sensitive (probGear, FALSE);
  gtk_tooltips_set_tip (Ui->tips, probGear, _("Planes can have problems with their landing gear"), NULL);

  probTerror = gtk_check_button_new_with_label (_("Terrorists"));
  gtk_widget_ref (probTerror);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "probTerror", probTerror,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (probTerror);
  gtk_table_attach (GTK_TABLE (table6), probTerror, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_sensitive (probTerror, FALSE);
  gtk_tooltips_set_tip (Ui->tips, probTerror, _("Hijackings, bombs, riots. It's a dangerous world out there."), NULL);

  probPilot = gtk_check_button_new_with_label (_("Drunken Pilots"));
  gtk_widget_ref (probPilot);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "probPilot", probPilot,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (probPilot);
  gtk_table_attach (GTK_TABLE (table6), probPilot, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_sensitive (probPilot, FALSE);
  gtk_tooltips_set_tip (Ui->tips, probPilot, _("There's nothing like a little booze in the cockpit at 30000feet"), NULL);

  probAlien = gtk_check_button_new_with_label (_("Aliens?"));
  gtk_widget_ref (probAlien);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "probAlien", probAlien,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (probAlien);
  gtk_table_attach (GTK_TABLE (table6), probAlien, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_sensitive (probAlien, FALSE);
  gtk_tooltips_set_tip (Ui->tips, probAlien, _("Little gray men flying around"), NULL);

  probBirds = gtk_check_button_new_with_label (_("Birds"));
  gtk_widget_ref (probBirds);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "probBirds", probBirds,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (probBirds);
  gtk_table_attach (GTK_TABLE (table6), probBirds, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_sensitive (probBirds, FALSE);
  gtk_tooltips_set_tip (Ui->tips, probBirds, _("There can be bird problems, especially at lower elevations"), NULL);

  label8 = gtk_label_new (_("Problems"));
  gtk_widget_ref (label8);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "label8", label8,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook1), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook1), 2), label8);

  table1 = gtk_table_new (2, 2, FALSE);
  gtk_widget_ref (table1);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "table1", table1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table1);
  gtk_box_pack_start (GTK_BOX (vbox3), table1, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (table1), 4);
  gtk_table_set_row_spacings (GTK_TABLE (table1), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table1), 5);

  label9 = gtk_label_new (_("Points per plane"));
  gtk_widget_ref (label9);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "label9", label9,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label9);
  gtk_table_attach (GTK_TABLE (table1), label9, 0, 1, 0, 1,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);

  label10 = gtk_label_new (_("Maximum points"));
  gtk_widget_ref (label10);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "label10", label10,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label10);
  gtk_table_attach (GTK_TABLE (table1), label10, 0, 1, 1, 2,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);

  g_snprintf(buff, 11, "%d", calc_plane_score(set));
  Ui->pref.pointsPerPlane = gtk_label_new (buff);
  gtk_widget_ref (Ui->pref.pointsPerPlane);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "pointsPerPlane", Ui->pref.pointsPerPlane,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (Ui->pref.pointsPerPlane);
  gtk_table_attach (GTK_TABLE (table1), Ui->pref.pointsPerPlane, 1, 2, 0, 1,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);

  g_snprintf(buff, 11, "%d", calc_max_score(set) );
  Ui->pref.pointsMax = gtk_label_new (buff);
  gtk_widget_ref (Ui->pref.pointsMax);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "pointsMax", Ui->pref.pointsMax,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (Ui->pref.pointsMax);
  gtk_table_attach (GTK_TABLE (table1), Ui->pref.pointsMax, 1, 2, 1, 2,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);

  hseparator2 = gtk_hseparator_new ();
  gtk_widget_ref (hseparator2);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "hseparator2", hseparator2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hseparator2);
  gtk_box_pack_start (GTK_BOX (vbox3), hseparator2, TRUE, TRUE, 0);

  hbox2 = gtk_hbox_new (TRUE, 0);
  gtk_widget_ref (hbox2);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "hbox2", hbox2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox2);
  gtk_box_pack_start (GTK_BOX (vbox3), hbox2, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbox2), 10);

  butOk = gnome_stock_button (GNOME_STOCK_BUTTON_OK);
  gtk_widget_ref (butOk);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "butOk", butOk,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (butOk);
  gtk_box_pack_start (GTK_BOX (hbox2), butOk, FALSE, FALSE, 0);

  butCancel = gnome_stock_button (GNOME_STOCK_BUTTON_CANCEL);
  gtk_widget_ref (butCancel);
  gtk_object_set_data_full (GTK_OBJECT (winPreferences), "butCancel", butCancel,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (butCancel);
  gtk_box_pack_start (GTK_BOX (hbox2), butCancel, FALSE, FALSE, 0);


  

/* sliders */
  gtk_signal_connect (GTK_OBJECT (adjNrOfPlanes), "value_changed",
                      GTK_SIGNAL_FUNC (pref_on_game_value_change),
                      &(Ui->pref.set->planeNr) );

  gtk_signal_connect (GTK_OBJECT (adjNrOfAirport), "value_changed",
                      GTK_SIGNAL_FUNC (pref_on_game_value_change),
                      &(Ui->pref.set->airportNr) );

  gtk_signal_connect (GTK_OBJECT (adjRoundSpeed), "value_changed",
                      GTK_SIGNAL_FUNC (pref_on_game_value_change),
                      &(Ui->pref.set->roundSpeed ) );

  gtk_signal_connect (GTK_OBJECT (adjGameDuration), "value_changed",
                      GTK_SIGNAL_FUNC (pref_on_game_value_change),
                      &(Ui->pref.set->gameDuration) );
  
  gtk_signal_connect (GTK_OBJECT (adjNearMiss), "value_changed",
		      GTK_SIGNAL_FUNC (pref_on_game_value_change),
                      &(Ui->pref.set->missDist) );

  gtk_signal_connect (GTK_OBJECT (adjAverageFuel), "value_changed",
                      GTK_SIGNAL_FUNC (pref_on_game_value_change),
                      &(Ui->pref.set->averageFuel) );
  
  gtk_signal_connect (GTK_OBJECT (adjReliability), "value_changed",
		      GTK_SIGNAL_FUNC (pref_on_reliability_value_change),
                      NULL);
  
  /* toggle buttons */
  gtk_signal_connect (GTK_OBJECT (objJetplane), "toggled",
                      GTK_SIGNAL_FUNC (pref_on_objJetplane_toggled),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (objPropPlanes), "toggled",
                      GTK_SIGNAL_FUNC (pref_on_objPropPlanes_toggled),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (objHelicopters), "toggled",
                      GTK_SIGNAL_FUNC (pref_on_objHelicopters_toggled),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (objNoflyzones), "toggled",
                      GTK_SIGNAL_FUNC (pref_on_objNoflyzones_toggled),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (objStormSystem), "toggled",
                      GTK_SIGNAL_FUNC (pref_on_objStormSystem_toggled),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (objPowerCables), "toggled",
                      GTK_SIGNAL_FUNC (pref_on_objPowerCables_toggled),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (objGroundFog), "toggled",
                      GTK_SIGNAL_FUNC (pref_on_objGroundFog_toggled),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (objMountains), "toggled",
                      GTK_SIGNAL_FUNC (pref_on_objMountains_toggled),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (probEngine), "toggled",
                      GTK_SIGNAL_FUNC (pref_on_probEngine_toggled),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (probGear), "toggled",
                      GTK_SIGNAL_FUNC (pref_on_probGear_toggled),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (probTerror), "toggled",
                      GTK_SIGNAL_FUNC (pref_on_probTerror_toggled),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (probPilot), "toggled",
                      GTK_SIGNAL_FUNC (pref_on_probPilot_toggled),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (probAlien), "toggled",
                      GTK_SIGNAL_FUNC (pref_on_probAlien_toggled),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (probBirds), "toggled",
                      GTK_SIGNAL_FUNC (pref_on_probBirds_toggled),
                      NULL);
  /* click buttons */
  gtk_signal_connect (GTK_OBJECT (butOk), "clicked",
                      GTK_SIGNAL_FUNC (pref_on_butOk_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (butCancel), "clicked",
                      GTK_SIGNAL_FUNC (pref_on_butCancel_clicked),
                      NULL);

/* window manager signals */
  gtk_signal_connect (GTK_OBJECT (winPreferences), "delete_event",
		      GTK_SIGNAL_FUNC (pref_win_close_btn_clicked), NULL);

  
  return winPreferences;
}

GtkWidget*
create_winHighScore (void)
{
  GtkWidget *winHighScore;
  GtkWidget *vbox4;
  GtkWidget *scrolledwindow1;
  GtkWidget *hsClist;
  GtkWidget *lblScore;
  GtkWidget *lblName;
  GtkWidget *lblDate;
  GtkWidget *hseparator3;
  GtkWidget *hbox3;
  GtkWidget *butOk;
  GtkWidget *butClear;

  winHighScore = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_object_set_data (GTK_OBJECT (winHighScore), "winHighScore", winHighScore);
  gtk_container_set_border_width (GTK_CONTAINER (winHighScore), 5);
  gtk_window_set_title (GTK_WINDOW (winHighScore), _("High Scores"));

  vbox4 = gtk_vbox_new (FALSE, 10);
  gtk_widget_ref (vbox4);
  gtk_object_set_data_full (GTK_OBJECT (winHighScore), "vbox4", vbox4,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox4);
  gtk_container_add (GTK_CONTAINER (winHighScore), vbox4);

  scrolledwindow1 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_ref (scrolledwindow1);
  gtk_object_set_data_full (GTK_OBJECT (winHighScore), "scrolledwindow1", scrolledwindow1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow1);
  gtk_box_pack_start (GTK_BOX (vbox4), scrolledwindow1, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow1), GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);

  hsClist = gtk_clist_new (3);
  gtk_widget_ref (hsClist);
  gtk_object_set_data_full (GTK_OBJECT (winHighScore), "hsClist", hsClist,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hsClist);
  gtk_container_add (GTK_CONTAINER (scrolledwindow1), hsClist);
  gtk_clist_set_column_width (GTK_CLIST (hsClist), 0, 80);
  gtk_clist_set_column_width (GTK_CLIST (hsClist), 1, 111);
  gtk_clist_set_column_width (GTK_CLIST (hsClist), 2, 80);
  gtk_clist_column_titles_show (GTK_CLIST (hsClist));
  gtk_clist_set_shadow_type (GTK_CLIST (hsClist), GTK_SHADOW_ETCHED_IN);

  lblScore = gtk_label_new (_("Score"));
  gtk_widget_ref (lblScore);
  gtk_object_set_data_full (GTK_OBJECT (winHighScore), "lblScore", lblScore,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (lblScore);
  gtk_clist_set_column_widget (GTK_CLIST (hsClist), 0, lblScore);

  lblName = gtk_label_new (_("Name"));
  gtk_widget_ref (lblName);
  gtk_object_set_data_full (GTK_OBJECT (winHighScore), "lblName", lblName,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (lblName);
  gtk_clist_set_column_widget (GTK_CLIST (hsClist), 1, lblName);

  lblDate = gtk_label_new (_("Date"));
  gtk_widget_ref (lblDate);
  gtk_object_set_data_full (GTK_OBJECT (winHighScore), "lblDate", lblDate,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (lblDate);
  gtk_clist_set_column_widget (GTK_CLIST (hsClist), 2, lblDate);

  hseparator3 = gtk_hseparator_new ();
  gtk_widget_ref (hseparator3);
  gtk_object_set_data_full (GTK_OBJECT (winHighScore), "hseparator3", hseparator3,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hseparator3);
  gtk_box_pack_start (GTK_BOX (vbox4), hseparator3, FALSE, TRUE, 0);

  hbox3 = gtk_hbox_new (TRUE, 0);
  gtk_widget_ref (hbox3);
  gtk_object_set_data_full (GTK_OBJECT (winHighScore), "hbox3", hbox3,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox3);
  gtk_box_pack_start (GTK_BOX (vbox4), hbox3, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbox3), 10);

  butOk = gnome_stock_button (GNOME_STOCK_BUTTON_OK);
  gtk_widget_ref (butOk);
  gtk_object_set_data_full (GTK_OBJECT (winHighScore), "butOk", butOk,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (butOk);
  gtk_box_pack_end (GTK_BOX (hbox3), butOk, FALSE, FALSE, 0);

  butClear = gtk_button_new_with_label (_("Clear High scores"));
  gtk_widget_ref (butClear);
  gtk_object_set_data_full (GTK_OBJECT (winHighScore), "butClear", butClear,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (butClear);
  gtk_box_pack_end (GTK_BOX (hbox3), butClear, FALSE, FALSE, 0);

  gtk_signal_connect (GTK_OBJECT (butOk), "clicked",
                      GTK_SIGNAL_FUNC (hs_on_butOk_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (butClear), "clicked",
                      GTK_SIGNAL_FUNC (hs_on_butClear_clicked),
                      NULL);

  return winHighScore;
}


GtkWidget *
build_game_board(uiBoard *board)
{
	GtkWidget* par = NULL;

	if(board->main != NULL)
	{ /* if the board already exists, destroy it, but save the parent */
		par = board->main->parent;
		gtk_widget_destroy(board->main);
	}
	board->main = gtk_table_new(AIR_BOARD_Y+2, AIR_BOARD_X+2, TRUE);
	gtk_widget_ref( board->main );
	gtk_object_set_data_full (GTK_OBJECT (board->main), "gameboard", board->main,
				  (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_set_usize (board->main, (AIR_BOARD_X+2)*AIR_SECTOR_X, (AIR_BOARD_Y+2)*AIR_SECTOR_Y);
	
        /* north button */
	board->n = gtk_button_new_with_label(_("N"));
	gtk_widget_ref(board->n);
	gtk_object_set_data_full (GTK_OBJECT (board->main), "boardn", board->n,
				  (GtkDestroyNotify) gtk_widget_unref);
	gtk_table_attach (GTK_TABLE(board->main), board->n, 
			  ( (AIR_BOARD_X+2)/2), ( (AIR_BOARD_X+2)/2)+1, 
			  0, 1,
			  (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
			  (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL), 0, 0);
	gtk_widget_show ( board->n );

	/* north east button */
	board->ne = gtk_button_new_with_label(_("NE"));
	gtk_widget_ref(board->ne);
	gtk_object_set_data_full (GTK_OBJECT (board->main), "boardne", board->ne,
				  (GtkDestroyNotify) gtk_widget_unref);
	gtk_table_attach (GTK_TABLE(board->main), board->ne, 
			  AIR_BOARD_X+1, AIR_BOARD_X+2, 
			  0, 1,
			  (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
			  (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL), 0, 0);
	gtk_widget_show ( board->ne );

	/* east button */
	board->e = gtk_button_new_with_label(_("E"));
	gtk_widget_ref(board->e);
	gtk_object_set_data_full (GTK_OBJECT (board->main), "boarde", board->e,
				  (GtkDestroyNotify) gtk_widget_unref);
	gtk_table_attach (GTK_TABLE(board->main), board->e, 
			  AIR_BOARD_X+1, AIR_BOARD_X+2, 
			  ( (AIR_BOARD_Y+2)/2), ( (AIR_BOARD_Y+2)/2)+1,
			  (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
			  (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL), 0, 0);
	gtk_widget_show ( board->e );

	/* South east button */
	board->se = gtk_button_new_with_label(_("SE"));
	gtk_widget_ref(board->se);
	gtk_object_set_data_full (GTK_OBJECT (board->main), "boardse", board->se,
				  (GtkDestroyNotify) gtk_widget_unref);
	gtk_table_attach (GTK_TABLE(board->main), board->se, 
			  AIR_BOARD_X+1, AIR_BOARD_X+2, 
			  AIR_BOARD_Y+1, AIR_BOARD_Y+2, 
			  (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
			  (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL), 0, 0);
	gtk_widget_show ( board->se );

	/* south button */
	board->s = gtk_button_new_with_label(_("S"));
	gtk_widget_ref(board->s);
	gtk_object_set_data_full (GTK_OBJECT (board->main), "boards", board->s,
				  (GtkDestroyNotify) gtk_widget_unref);
	gtk_table_attach (GTK_TABLE(board->main), board->s, 
			  ( (AIR_BOARD_X+2)/2), ( (AIR_BOARD_X+2)/2)+1, 
			  AIR_BOARD_X+1, AIR_BOARD_X+2,
			  (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
			  (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL), 0, 0);
	gtk_widget_show ( board->s );

	/* South west button */
	board->sw = gtk_button_new_with_label(_("SW"));
	gtk_widget_ref(board->sw);
	gtk_object_set_data_full (GTK_OBJECT (board->main), "boardsw", board->sw,
				  (GtkDestroyNotify) gtk_widget_unref);
	gtk_table_attach (GTK_TABLE(board->main), board->sw, 
			  0,1,
			  AIR_BOARD_Y+1, AIR_BOARD_Y+2, 
			  (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
			  (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL), 0, 0);
	gtk_widget_show ( board->sw );

	/* West button */
	board->w = gtk_button_new_with_label(_("W"));
	gtk_widget_ref(board->w);
	gtk_object_set_data_full (GTK_OBJECT (board->main), "boardw", board->w,
				  (GtkDestroyNotify) gtk_widget_unref);
	gtk_table_attach (GTK_TABLE(board->main), board->w, 
			  0,1,
			  ( (AIR_BOARD_Y+2)/2), ( (AIR_BOARD_Y+2)/2)+1,
			  (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
			  (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL), 0, 0);
	gtk_widget_show ( board->w );


	/* North west button */
	board->nw = gtk_button_new_with_label(_("NW"));
	gtk_widget_ref(board->nw);
	gtk_object_set_data_full (GTK_OBJECT (board->main), "boardnw", board->nw,
				  (GtkDestroyNotify) gtk_widget_unref);
	gtk_table_attach (GTK_TABLE(board->main), board->nw, 
			  0,1,
			  0,1,
			  (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
			  (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL), 0, 0);
	gtk_widget_show ( board->nw );
	
	if(par != NULL) { /* attach the new board to the parent, if there was one. */
		gtk_box_pack_start (GTK_BOX (par), board->main, TRUE, TRUE, 0);
		gtk_box_reorder_child(GTK_BOX(par), board->main, 0);
	}

	/* show the table as last, to avoid ugly updating */
	gtk_widget_show( board->main );
	
	return(board->main);
}


void
build_result_board(airScore *score)
{
	GtkWidget *window1;
	GtkWidget *vbox1;
	GtkWidget *label1;
	GtkWidget *table1;
	GtkWidget *scoreLbl;
	GtkWidget *scoreRes;
	GtkWidget *missLbl;
	GtkWidget *saveLbl;
	GtkWidget *miss;
	GtkWidget *correct;
	GtkWidget *hbox2;
	GtkWidget *newGame;
	GtkWidget *okay;

	g_assert(score != NULL);

  window1 = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_object_set_data (GTK_OBJECT (window1), "window1", window1);
  gtk_window_set_title (GTK_WINDOW (window1), _("AirTraffic results!"));

  vbox1 = gtk_vbox_new (FALSE, 0);
  gtk_widget_ref (vbox1);
  gtk_object_set_data_full (GTK_OBJECT (window1), "vbox1", vbox1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox1);
  gtk_container_add (GTK_CONTAINER (window1), vbox1);

  label1 = gtk_label_new (_("The game has ended!"));
  gtk_widget_ref (label1);
  gtk_object_set_data_full (GTK_OBJECT (window1), "label1", label1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label1);
  gtk_box_pack_start (GTK_BOX (vbox1), label1, FALSE, FALSE, 0);

  table1 = gtk_table_new (3, 2, TRUE);
  gtk_widget_ref (table1);
  gtk_object_set_data_full (GTK_OBJECT (window1), "table1", table1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table1);
  gtk_box_pack_start (GTK_BOX (vbox1), table1, FALSE, TRUE, 4);

  scoreLbl = gtk_label_new (_("Total score"));
  gtk_widget_ref (scoreLbl);
  gtk_object_set_data_full (GTK_OBJECT (window1), "scoreLbl", scoreLbl,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scoreLbl);
  gtk_table_attach (GTK_TABLE (table1), scoreLbl, 0, 1, 0, 1,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);

  scoreRes = gtk_label_new (g_strdup_printf("%d", score->points));
  gtk_widget_ref (scoreRes);
  gtk_object_set_data_full (GTK_OBJECT (window1), "score", scoreRes,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scoreRes);
  gtk_table_attach (GTK_TABLE (table1), scoreRes, 1, 2, 0, 1,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);

  missLbl = gtk_label_new (_("Total near-misses"));
  gtk_widget_ref (missLbl);
  gtk_object_set_data_full (GTK_OBJECT (window1), "missLbl", missLbl,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (missLbl);
  gtk_table_attach (GTK_TABLE (table1), missLbl, 0, 1, 1, 2,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);

  saveLbl = gtk_label_new (_("Total correct planes"));
  gtk_widget_ref (saveLbl);
  gtk_object_set_data_full (GTK_OBJECT (window1), "saveLbl", saveLbl,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (saveLbl);
  gtk_table_attach (GTK_TABLE (table1), saveLbl, 0, 1, 2, 3,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);

  miss = gtk_label_new (g_strdup_printf("%d", score->nearmiss));
  gtk_widget_ref (miss);
  gtk_object_set_data_full (GTK_OBJECT (window1), "miss", miss,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (miss);
  gtk_table_attach (GTK_TABLE (table1), miss, 1, 2, 1, 2,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);

  correct = gtk_label_new (g_strdup_printf("%d", score->correct));
  gtk_widget_ref (correct);
  gtk_object_set_data_full (GTK_OBJECT (window1), "correct", correct,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (correct);
  gtk_table_attach (GTK_TABLE (table1), correct, 1, 2, 2, 3,
                    (GtkAttachOptions) (0),
                   (GtkAttachOptions) (0), 0, 0);

  hbox2 = gtk_hbox_new (TRUE, 0);
  gtk_widget_ref (hbox2);
  gtk_object_set_data_full (GTK_OBJECT (window1), "hbox2", hbox2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox2);
  gtk_box_pack_start (GTK_BOX (vbox1), hbox2, FALSE, FALSE, 2);

  newGame = gtk_button_new_with_label (_("New Game"));
  gtk_widget_ref (newGame);
  gtk_object_set_data_full (GTK_OBJECT (window1), "newGame", newGame,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (newGame);
  gtk_box_pack_start (GTK_BOX (hbox2), newGame, FALSE, FALSE, 0);

  okay = gtk_button_new_with_label (_("Okay"));
  gtk_widget_ref (okay);
  gtk_object_set_data_full (GTK_OBJECT (window1), "okay", okay,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (okay);
  gtk_box_pack_start (GTK_BOX (hbox2), okay, FALSE, FALSE, 0);
  
  gtk_widget_show(window1);

  /* click buttons */
  gtk_signal_connect (GTK_OBJECT (okay), "clicked",
		      GTK_SIGNAL_FUNC (results_on_okay_clicked),
                      NULL);

  gtk_signal_connect (GTK_OBJECT (newGame), "clicked",
		      GTK_SIGNAL_FUNC (results_on_newgame_clicked),
                      NULL);
  
/* window manager signals */
  gtk_signal_connect (GTK_OBJECT (window1), "delete_event",
		      GTK_SIGNAL_FUNC (results_win_close_btn_clicked), NULL);
  
}


void
build_crash_board()
{
	GtkWidget *winCrash;
	GtkWidget *dialog_vbox1;
	GtkWidget *button5;
	GtkWidget *dialog_action_area1;

	winCrash = gnome_message_box_new (_("You look up from your console, as a fire ball lights up the\ndistant horizon. You know then, that you'd better go find a new job.\n\nBe happy it's only a Game! :)"), GNOME_MESSAGE_BOX_WARNING, NULL);
	gtk_object_set_data (GTK_OBJECT (winCrash), "winCrash", winCrash);
	gtk_window_set_position (GTK_WINDOW (winCrash), GTK_WIN_POS_CENTER);
	gtk_window_set_policy (GTK_WINDOW (winCrash), FALSE, FALSE, FALSE);
	gnome_dialog_set_close (GNOME_DIALOG (winCrash), TRUE);
	
	dialog_vbox1 = GNOME_DIALOG (winCrash)->vbox;
	gtk_object_set_data (GTK_OBJECT (winCrash), "dialog_vbox1", dialog_vbox1);
	gtk_widget_show (dialog_vbox1);

	gnome_dialog_append_button (GNOME_DIALOG (winCrash), GNOME_STOCK_BUTTON_OK);
	button5 = g_list_last (GNOME_DIALOG (winCrash)->buttons)->data;
	gtk_widget_ref (button5);
	gtk_object_set_data_full (GTK_OBJECT (winCrash), "button5", button5,
				  (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show (button5);
	GTK_WIDGET_SET_FLAGS (button5, GTK_CAN_DEFAULT);
	
	dialog_action_area1 = GNOME_DIALOG (winCrash)->action_area;
	gtk_widget_ref (dialog_action_area1);
	gtk_object_set_data_full (GTK_OBJECT (winCrash), "dialog_action_area1", dialog_action_area1,
				  (GtkDestroyNotify) gtk_widget_unref);
	gtk_widget_show(dialog_action_area1);
	gtk_widget_show(winCrash);
};	

void
build_about_win(void)
{
  const gchar *authors[] = {
    "Marijn Vriens <marijn@sanity.dhs.org>",
    NULL
  };
  GtkWidget *aboutwin;

  aboutwin = gnome_about_new ("airtraffic", VERSION,
                        _("Copyright 2000 Marijn Vriens"),
                        authors,
                        _("An air traffic controller simulation game.\nWeb: airtraffic.sourceforge.net"),
                        NULL);
  gtk_object_set_data (GTK_OBJECT (aboutwin), "aboutwin", aboutwin);
  gtk_window_set_modal (GTK_WINDOW (aboutwin), TRUE);
  gtk_widget_show(aboutwin);
}


/* ChangeLog
 * $Log: ifstatic.c,v $
 * Revision 1.14  2000/04/30 17:21:09  marijn
 * Added a about window.
 *
 * Revision 1.13  2000/04/28 18:56:32  marijn
 * Removed unused callbacks. Progressbar-click now ends a round.
 *
 * Revision 1.12  2000/04/27 23:25:56  marijn
 * Clean up the game board after a game.
 *
 * Revision 1.11  2000/04/24 23:30:16  marijn
 * Added callbacks for results window. Fixed scoring bug.
 *
 * Revision 1.10  2000/04/20 18:57:07  marijn
 * Scores per plane and maximum are now shown according the game settings.
 *
 * Revision 1.9  2000/04/19 20:41:40  marijn
 * Added the proper callbacks when WM closes windows. Updated preferences
 *
 * Revision 1.8  2000/04/19 05:54:44  marijn
 * Functioning preferences in a new preference window.
 *
 * Revision 1.7  2000/04/16 17:03:45  marijn
 * Removed references to the obsolete support header files.
 *
 * Revision 1.6  2000/04/01 16:55:47  marijn
 * Major source code reordering, added license information.
 *
 * Revision 1.5  2000/03/27 00:16:08  marijn
 * Further proximity support. Rudimentary game scoring implemented.
 *
 * Revision 1.4  2000/03/08 23:34:53  marijn
 * The game now has a proper ending. "End Game" added to the menu.
 *
 * Revision 1.3  2000/03/07 21:04:48  marijn
 * changed all simple on_togg*_toggled callbacks for one on_toggDir_toggled
 *
 * Revision 1.2  2000/02/20 23:57:14  marijn
 * Moved build_game_board() to ifstatic.c .
 * AirTraffic is now a Gnome build.
 *
 * Revision 1.1  2000/02/18 20:13:24  marijn
 * Split interface.c into ifdynamic.c and ifstatic.c
 *
 */
