/* Functions that init the datastructures.
 * $Id: init.c,v 1.5 2000/04/28 18:39:40 marijn Exp $

 * An air traffic simulation game. 
 * Copyright (C) 2000  Marijn Vriens <marijn@sanity.dhs.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include "gnome.h"

#include "defaults.h"
#include "datastructs.h"
#include "prefs.h"
#include "utils.h"

airSetting* /* set lots of settings to a sane state */
initSettings(void) 
{
	airSetting *set       = g_new( airSetting, 1 );

	set->roundSpeed   = AIR_ROUNDSPEED;
	set->gameDuration = AIR_GAMEDURATION;
	set->planeNr      = AIR_NROFAIRCRAFT;
	set->airportNr    = AIR_NROFAIRPORT;
	set->averageFuel  = 0;
				
	set->missDist     = AIR_MISSDIST;
	set->crashDist    = AIR_CRASHDIST;
	set->initMinPlaneDist=0;

	set->objJetplane = TRUE;
	set->objPropPlanes = FALSE;
	set->objHelicopters = FALSE;
	set->objNoflyzones = FALSE;
	set->objStormSystem = FALSE;
	set->objPowerCables = FALSE;
	set->objGroundFog = FALSE;
	set->objMountains = FALSE;

	set->probEngine = FALSE;
	set->probGear = FALSE;
	set->probTerror = FALSE;
	set->probPilot = FALSE;
	set->probAlien = FALSE;
	set->probBrids = FALSE;

	prefRead(set);
	/* scores of the plane */
	set->score.points     = 0;
	set->score.correct    = 0;
	set->score.nearmiss   = 0;
	set->score.planeval   = calc_plane_score(set);
	
	return set;
}

void /* initialize the differend object and plane types in the game */
initTypes(airSetting *settings) 
{
	/* make the object types */
	settings->otype[AIRPORT].land       = TRUE; /* that's the airport */
	settings->otype[AIRPORT].fly        = TRUE;
	settings->otype[AIRPORT].speed      = 0;
	settings->otype[AIRPORT].height     = 0;
	settings->otype[ENTRY_POINT].land   = TRUE; /* that's the entry point */
	settings->otype[ENTRY_POINT].fly    = TRUE;
	settings->otype[ENTRY_POINT].speed  = 0;
	settings->otype[ENTRY_POINT].height = 0;
	
	/* make the plane types */
	/* jet plane = 0 */
	settings->ptype[JET].speed = AIR_JET_SPEED;
	settings->ptype[JET].turn  = AIR_JET_TURN;
	settings->ptype[JET].hover = AIR_JET_HOVER;
	settings->ptype[JET].id    = AIR_JET_ID;
/*	settings->ptype[JET].name  = AIR_JET_NAME; */
}

/* ChangLog
 * --------
 * $Log: init.c,v $
 * Revision 1.5  2000/04/28 18:39:40  marijn
 * Now uses compile-time values.
 *
 * Revision 1.4  2000/04/24 23:30:16  marijn
 * Added callbacks for results window. Fixed scoring bug.
 *
 * Revision 1.3  2000/04/20 22:44:31  marijn
 * Fixed settigns init problem and fixed some small compiler warnings.
 *
 * Revision 1.2  2000/04/16 17:12:31  marijn
 * Added support for saving preferences and highscores to preference files.
 *
 * Revision 1.1  2000/04/01 16:55:47  marijn
 * Major source code reordering, added license information.
 *
 */
