/* Functions for the User interface functions and it's datastructures.
 * $Id: interface.h,v 1.18 2000/04/30 17:21:09 marijn Exp $

 * An air traffic simulation game. 
 * Copyright (C) 2000  Marijn Vriens <marijn@sanity.dhs.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 */

typedef struct {
/* height control slider */
	GtkWidget* h;
	GtkObject* hAdj;
	GtkWidget* hLabel; 


/* direction control buttons */
	GtkWidget* n; 
	GtkWidget* ne;
	GtkWidget* e;
	GtkWidget* se;
	GtkWidget* s;
	GtkWidget* sw;
	GtkWidget* w;
	GtkWidget* nw; 
	GtkWidget* c;

	GtkWidget* rl;   /* rotate left    */
	GtkWidget* rr;   /* rotate right   */
	GtkWidget* park; /* parking patern */

/* time control */
	GtkWidget* time;
	gint       timer;
} uiCtrl;

typedef struct { /* Entry points in the board */
	GtkWidget* main;
	GtkWidget* nw; 
	GtkWidget* n; 
	GtkWidget* ne;
	GtkWidget* w;
	GtkWidget* e;
	GtkWidget* sw;
	GtkWidget* s;
	GtkWidget* se;
} uiBoard;

typedef struct {
	GtkWidget* pointsPerPlane;
	GtkWidget* pointsMax;
	airSetting* set; /* pointer to temporary structure with settings */
} uiPref;

typedef struct { /* general interface stucture */
        airPlane*  select;  /* the currently selected plane */
        uiCtrl     ctrl;    /* structure with plane control buttons */
	uiBoard    board;   /* structure with board widgets */
	uiPref     pref;    /* structure with preferences */
	GtkWidget* flist;   /* pointer to the list with flights */
	GtkWidget* winPref; /* preference window */
	GtkWidget* main;    /* main game window */
	GtkTooltips* tips;  /* tool tips for the game */
} ui;

ui* initUi(void);
GtkWidget* create_winCtrl(ui *);
GtkWidget* create_winPref(ui *, airSetting *);

void loadFlightList(GtkCList *list, GList *planes);
void clearFlightList(GtkCList *list);
void game_timer_start(void);
void game_timer_stop(void);
GtkWidget* build_game_board(uiBoard *);
void game_board_clean(ui *);
void build_result_board(airScore *);
void build_crash_board(void);
void build_about_win(void);
void update_game_board(GtkWidget *board);
void plane_dir_change(gint direction);
void move_plane(airPlane *, gchar, gboolean);
void move_object(airObj *object);
void remove_plane(airPlane *plane);

ui*        airUi;

/* ChangeLog
 * $Log: interface.h,v $
 * Revision 1.18  2000/04/30 17:21:09  marijn
 * Added a about window.
 *
 * Revision 1.17  2000/04/27 23:25:56  marijn
 * Clean up the game board after a game.
 *
 * Revision 1.16  2000/04/19 05:54:44  marijn
 * Functioning preferences in a new preference window.
 *
 * Revision 1.15  2000/04/01 16:55:47  marijn
 * Major source code reordering, added license information.
 *
 * Revision 1.14  2000/03/27 00:16:08  marijn
 * Further proximity support. Rudimentary game scoring implemented.
 *
 * Revision 1.13  2000/03/08 23:34:53  marijn
 * The game now has a proper ending. "End Game" added to the menu.
 *
 * Revision 1.12  2000/01/17 01:39:22  marijn
 * Planes now keep to be the same widgets when they only move.
 * Improved color responce.
 * Added initail support for removing planes when they leave the board.
 *
 * Revision 1.11  2000/01/05 15:03:36  marijn
 * Added basic support for airport images
 *
 * Revision 1.10  1999/12/26 03:21:01  marijn
 * Planes now have xpm images for them.
 * Added comments to much of the global structures.
 *
 * Revision 1.9  1999/12/10 21:25:22  marijn
 * Added comments and cleaned gameRound() in game.c
 * Added structure for keeping track scored points.
 *
 * Revision 1.8  1999/09/26 12:32:42  marijn
 * planes turn the correct way.
 * clicking on the plane now selects it in the list
 * fixed dubble timing problem
 *
 * Revision 1.7  1999/09/19 18:34:15  marijn
 * Plane selection in the list works.. Information in the list is better.
 * Control buttons now represent plane status.
 *
 * Revision 1.6  1999/09/17 13:45:24  marijn
 * detection that a plane leaves works
 *
 * Revision 1.5  1999/09/13 19:43:48  marijn
 * main game round code inserted..
 *
 * Revision 1.4  1999/08/27 13:29:29  marijn
 * planes are get added to the planelist
 *
 * Revision 1.3  1999/08/26 22:15:50  marijn
 * toggle buttons are now a group of radio buttons and height slider works
 *
 * Revision 1.2  1999/08/22 18:21:01  marijn
 * types and objects are generated as is the list of planes.
 *
 */
