/* Functions for handling lists
 * $Id: lists.c,v 1.4 2000/04/30 16:34:16 marijn Exp $

 * An air traffic simulation game. 
 * Copyright (C) 2000  Marijn Vriens <marijn@sanity.dhs.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <math.h>

#include "gnome.h"

#include "defaults.h"
#include "datastructs.h"
#include "tests.h"
#include "utils.h"

gint
randDistForAirportLocation(gfloat, gint);

GList* /* generate the list with objects in the game */
genObjList(airSetting *settings) {
	GList *objList = NULL;
	gint i;
	airObj *temp = NULL;

	/* generate the entry points, they are fixed */
	/* top row */
	temp = g_new(airObj, 1); /* North West */
	temp->pos.x = 0; 
	temp->pos.y = 0;
	temp->pos.z = -1;
	temp->pos.heading= 315;
	temp->type  = &(settings->otype[ENTRY_POINT]);
	temp->name  = g_strdup_printf("nw");
	temp->id    = -1;
	objList = g_list_prepend(objList, temp); /* Binds new object to the list */

	temp = g_new(airObj, 1); /* North */
	temp->pos.x = AIR_BOARD_X / 2 ; 
	temp->pos.y = 0;
	temp->pos.z = -1;
	temp->pos.heading= 0;
	temp->type  = &(settings->otype[ENTRY_POINT]);
	temp->name  = g_strdup_printf("n");
	temp->id    = -1;
	objList = g_list_prepend(objList, temp);

	temp = g_new(airObj, 1); /* North EAST */
	temp->pos.x = AIR_BOARD_X-1; 
	temp->pos.y = 0;
	temp->pos.z = -1;
	temp->pos.heading= 45;
	temp->type  = &(settings->otype[ENTRY_POINT]);
	temp->name  = g_strdup_printf("ne");
	temp->id    = -1;
	objList = g_list_prepend(objList, temp);

	/* middle row */
	temp = g_new(airObj, 1); /* WEST */
	temp->pos.x = 0; 
	temp->pos.y = AIR_BOARD_Y / 2;
	temp->pos.z = -1;
	temp->pos.heading= 270;
	temp->type  = &(settings->otype[ENTRY_POINT]);
	temp->name  = g_strdup_printf("w");
	temp->id    = -1;
	objList = g_list_prepend(objList, temp);

	temp = g_new(airObj, 1); /* EAST */
	temp->pos.x = AIR_BOARD_X-1; 
	temp->pos.y = AIR_BOARD_Y / 2;
	temp->pos.z = -1;
	temp->pos.heading= 90;
	temp->type  = &(settings->otype[ENTRY_POINT]);
	temp->name  = g_strdup_printf("e");
	temp->id    = -1;
	objList = g_list_prepend(objList, temp);

	/* Bottom row */
	temp = g_new(airObj, 1); /* South WEST */
	temp->pos.x = 0; 
	temp->pos.y = AIR_BOARD_Y-1;
	temp->pos.z = -1;
	temp->pos.heading= 225;
	temp->type  = &(settings->otype[ENTRY_POINT]);
	temp->name  = g_strdup_printf("sw");
	temp->id    = -1;
	objList = g_list_prepend(objList, temp);

	temp = g_new(airObj, 1); /* South */
	temp->pos.x = AIR_BOARD_X / 2;
	temp->pos.y = AIR_BOARD_Y-1;
	temp->pos.z = -1;
	temp->pos.heading= 180;
	temp->type  = &(settings->otype[ENTRY_POINT]);
	temp->name  = g_strdup_printf("s");
	temp->id    = -1;
	objList = g_list_prepend(objList, temp);

	temp = g_new(airObj, 1); /* South EAST */
	temp->pos.x = AIR_BOARD_X-1;
	temp->pos.y = AIR_BOARD_Y-1;
	temp->pos.z = -1;
	temp->pos.heading= 135;
	temp->type  = &(settings->otype[ENTRY_POINT]);
	temp->id    = -1;
	temp->name  = g_strdup_printf("se");
	objList = g_list_prepend(objList, temp);

	/* Generate the airports */
	for( i=0; i < settings->airportNr; i++ ) {
		temp = g_new(airObj, 1); /* Alloc memory for new object */
		/* set values; */
		temp->pos.x = randDistForAirportLocation((float) rand() / RAND_MAX, AIR_BOARD_X);
		temp->pos.y = randDistForAirportLocation((float) rand() / RAND_MAX, AIR_BOARD_Y);
		temp->pos.z = 0;
		temp->pos.heading = -1;
		temp->type  = &(settings->otype[AIRPORT]);
		temp->widget= NULL;
		temp->id    = i;
		temp->name  = g_strdup_printf("ap%d", i+1);
		objList = g_list_prepend(objList, temp); /* Binds new object to the list */

//		g_print("airport nr:%d x=%d y=%d\n", i, temp->pos.x, temp->pos.y);

	}
	return objList;
}


GList * /* release the memory associated with the objects */
freeObjList(GList *objs)
{
	airObj *temp = NULL;
	if(objs == NULL) {
		return NULL;
	}
	g_list_first(objs);
	do {
		temp = objs->data;
		g_free(temp->name); /* free the memory of the objects name */ 
		temp->name = NULL;
		g_free(temp); /* free the memory of the object */
		temp = NULL;
	} while ( (objs = g_list_next(objs)) != NULL );
	g_list_free(objs); /* de-allocate the memory of linked list */
	return objs;
}


GList* /* generate a list with planes */
genPlaneList (airSetting *settings, GList *Objs)
{
	GList *planeList = NULL;
	gint i;
	gint nrOfObj   = g_list_length(Objs);
	gchar *mtime;
	airPlane *temp = NULL;

	/* Generate the planes */
	for( i=0; i < settings->planeNr; i++ ) {
		temp = g_new(airPlane, 1); /* alloc the mem */
		temp->widget = NULL;
		temp->pos.x = -1;
		temp->pos.y = -1;
		temp->pos.z = -1;
		temp->cmd.x = -1;
		temp->cmd.y = -1;
		temp->cmd.z = -1;
		temp->cmd.heading = -1;
		temp->fuel = 0;
		temp->type  = &(settings->ptype[JET]); /* the type is a jet */
		temp->inTime= ( (float) ( (float) rand() / RAND_MAX ) * /* the plane enter time */
				( (float) ( settings->gameDuration * 60 ) / settings->roundSpeed ) );
		temp->inTime *= settings->roundSpeed;
		/* places where planes come in and go out */
		temp->in    = g_list_nth_data(Objs, ( (float) ( (float) rand() / RAND_MAX ) * nrOfObj ) );
		temp->out   = g_list_nth_data(Objs, ( (float) ( (float) rand() / RAND_MAX ) * nrOfObj ) );
		if( temp->in->pos.z == 0 ) { /* decide the starting hight, should be 0 if starts on */
			temp->inHeight = 0;  /* airport */
		} else {
			temp->inHeight = ( (float) ( (float) rand() / RAND_MAX ) * (AIR_BOARD_Z-1) )+1;
		}
		if( temp->out->pos.z == 0 ) { /* deside the finishing height, */
			temp->outHeight = 0;/* should be 0 if the plane ends on an airport */
		} else {
			temp->outHeight = ( (float) ( (float) rand() / RAND_MAX ) * (AIR_BOARD_Z-1) )+1;
		}

		/* test if this is not too close to an other plane */
		if( testPlanesDist(planeList, temp) < settings->initMinPlaneDist ) { 
			/* plane is too close to an other */

//			g_print("Plane nr:%2d DROPED!\n", i);

			g_free(temp); /* drop the memory allocated for this plane */
			temp = NULL;
			i--;
			continue;
		}
		
		if( temp->in->pos.heading == -1 ) { /* see what the initial heading of the planes
						       should be. random for an airfield */
			temp->pos.heading = ( (float) ( (float) rand() / RAND_MAX ) * 7 );
			temp->pos.heading *= 45;
		} else {
			temp->pos.heading = temp->in->pos.heading + 180;
			if( temp->pos.heading >= 360 ) {
				temp->pos.heading -= 360;
			}
		}
		planeList = g_list_prepend(planeList, temp);

 	        mtime = secsToMinutes(temp->inTime); 
 		g_print("Plane nr:%2d at:%s d=%2d | ", i, mtime, testPlanesDist(planeList, temp)); 
 		g_print("in=%2d,%2d,%2d,%3d | ", temp->in->pos.x, temp->in->pos.y,  
 			temp->inHeight, temp->pos.heading); 
 		g_print("out=%2d,%2d,%2d,%3d\n", temp->out->pos.x, temp->out->pos.y, 
 			temp->outHeight, temp->out->pos.heading); 
 			g_free(mtime); 
	}

	planeList = g_list_sort(planeList, testTimes);
  
	return planeList;
}

GList * /* release memory associated with the planes in the list */
freePlaneList(GList *planes)
{
	airPlane *temp = NULL;

	if(planes == NULL) {
		return NULL;
	}
	
	do {
		temp = planes->data;
		g_assert( planes->data != NULL );
		g_free(temp); /* free the memory for this plane */
		planes->data = NULL;
	} while( (planes = g_list_next(planes)) != NULL);
	g_list_free(planes); /* free the memory for the linked list it self */
	return NULL;
}

void /* Dump information on a list to screen */
dumpListPtrs(GList *list)
{
	guint firstNode = GPOINTER_TO_INT(list);
	list = g_list_first(list);
	if(list == NULL) {
		g_print("List %x is empty\n", GPOINTER_TO_INT(list));
	} else {
		guint nr, i = 0;
		nr = g_list_length(list);
		do {
			g_print("List %x : %d(%d) contains: %x\n", firstNode,
				i++, nr, GPOINTER_TO_INT(list->data));
		} while ((list = g_list_next(list)) != NULL);
	}
}

gint /* the function that distributes the airport on the playing field */
randDistForAirportLocation(gfloat value, gint max) {
	gint out, edge;
/* the most obvious placement function for airports */
	/* out = value*max; */

	/* distribution is 100% random, but the edges are avoided */
	/* edge = 3;
	 * out = (value*(max-2*edge))+edge; */
	
	/* limmits the ocurence of airports near the edges, but they
	   end up too much in the dead center of the board. */
	/* out = (0.5*pow(2.0*value-1.0,3)+0.5)*max; */

	/* This function has the same effect, only the airports are
	   concentrated in a ring around the center. and extreem edge
	   is avoided. */
	edge = 2;
	out = ( (value+0.2*sin(2*M_PI*value))*(max-2*edge) )+edge;
	
	g_assert(out >= 0); /* make sure the math results are still sane :) */
	g_assert(out <= max);
	
	return out;
}


/* ChangLog
 * $Log: lists.c,v $
 * Revision 1.4  2000/04/30 16:34:16  marijn
 * Airports are now no longer put on the edge of the board.
 *
 * Revision 1.3  2000/04/24 23:30:16  marijn
 * Added callbacks for results window. Fixed scoring bug.
 *
 * Revision 1.2  2000/04/24 14:51:28  marijn
 * Added different airport images.
 *
 * Revision 1.1  2000/04/01 16:55:47  marijn
 * Major source code reordering, added license information.
 *
 */
