/* Functions for reading writing preferences, including highscores.
 * $Id: prefs.c,v 1.6 2000/04/20 22:44:31 marijn Exp $

 * An air traffic simulation game. 
 * Copyright (C) 2000  Marijn Vriens <marijn@sanity.dhs.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 */

#include <config.h>

#include "gnome.h"

#include "defaults.h"
#include "datastructs.h"
#include "tests.h"

void
prefReadNormal(airSetting*);

void
prefReadLegacy(airSetting*, gchar*);

void
prefLoadDefaults(airSetting*);


void
highScoreWrite(GList *hsl) {
	gint i;
	gchar path[256];
	airHighScore *temp;
	if(hsl != NULL) {
		i = 0;
		do {
			temp = hsl->data;
			g_snprintf(path, 255, "/%s/highScore/%d", PACKAGE , i);
			gnome_config_set_int(path, temp->score);
			g_snprintf(path, 255, "/%s/highMax/%d", PACKAGE , i);
			gnome_config_set_int(path, temp->max);
			g_snprintf(path, 255, "/%s/highName/%d", PACKAGE , i);
			gnome_config_set_string(path, temp->name);
			g_snprintf(path, 255, "/%s/highTime/%d", PACKAGE , i);
			gnome_config_set_int(path, temp->time);
			
			i++;	
		} while( (hsl = g_list_next(hsl)) != NULL);
	}
}


GList *
highScoreRead(void) {
	gpointer config_iterator;
	gint i;
	gchar *key, *value, path[256];
	
	GList* hsl = NULL;
	airHighScore* temp;

	g_snprintf(path, 255, "/%s/highScore/", PACKAGE );
	config_iterator = gnome_config_init_iterator(path);

	if(config_iterator != NULL) {
		i = 0;
		while((config_iterator = gnome_config_iterator_next(config_iterator, &
								    key, &value))) {
			if(key == 0 || value == 0) {
				if(key) g_free(key);
				if(value) g_free(value);
				continue;
			}
			temp = g_new(airHighScore, 1);
			temp->score = atoi(value);

			g_snprintf(path, 255, "/%s/highMax/%s", PACKAGE , key);
			temp->max = gnome_config_get_int(path);
			g_snprintf(path, 255, "/%s/highName/%s", PACKAGE , key);
			temp->name = gnome_config_get_string(path);
			g_snprintf(path, 255, "/%s/highTime/%s", PACKAGE , key);
			temp->time = gnome_config_get_int(path);

			if(temp->time == 0) {
				g_assert_not_reached();
			}
			
			hsl = g_list_insert_sorted(hsl, temp, testHighScore);
			if(i++ >= AIR_MAX_HIGHSCORES) { break; }
		}
	}
	return hsl; 
}

void /* test if and what kind of preference file there is, and read that in */
prefRead(airSetting* set) {
	gchar* savedVersion, path[256];
	gboolean used_default;
	
	g_assert(set);

	g_snprintf(path, 255, "/%s/misc/version=%s", PACKAGE , VERSION );
	savedVersion = gnome_config_get_string_with_default(path, &used_default);

	if(used_default != TRUE) { /* there was preference file */
		if(strcmp(savedVersion, VERSION ) == 0) { /* saved by the current version */
			prefReadNormal(set);
		} else {
			prefReadLegacy(set, savedVersion);
		}
		
	} else { /* no preference file found */
		prefReadLegacy(set, "0");
	}
}

void prefWrite(airSetting* set) {

	gchar path[256];

	g_assert(set);

	g_snprintf(path, 255, "/%s/misc/version", PACKAGE);
	gnome_config_set_string(path, VERSION );
	g_snprintf(path, 255, "/%s/game/roundSpeed", PACKAGE);
	gnome_config_set_int(path, set->roundSpeed);
	g_snprintf(path, 255, "/%s/game/duration", PACKAGE);
	gnome_config_set_int(path, set->gameDuration);
	g_snprintf(path, 255, "/%s/game/nrOfAircraft", PACKAGE);
	gnome_config_set_int(path, set->planeNr);
	g_snprintf(path, 255, "/%s/game/nrOfAirport", PACKAGE);
	gnome_config_set_int(path, set->airportNr);
	g_snprintf(path, 255, "/%s/game/missDist", PACKAGE);
	gnome_config_set_int(path, set->missDist);
	g_snprintf(path, 255, "/%s/game/crashDist", PACKAGE);
	gnome_config_set_int(path, set->crashDist);
	g_snprintf(path, 255, "/%s/game/averageFuel", PACKAGE);
	gnome_config_set_int(path, set->averageFuel);
	
	g_snprintf(path, 255, "/%s/game/objJetplane", PACKAGE);
	gnome_config_set_bool(path, set->objJetplane);
	g_snprintf(path, 255, "/%s/game/objPropPlanes", PACKAGE);
	gnome_config_set_bool(path, set->objPropPlanes);
	g_snprintf(path, 255, "/%s/game/objHelicopters", PACKAGE);
	gnome_config_set_bool(path, set->objHelicopters);

	g_snprintf(path, 255, "/%s/game/objPropPlanes", PACKAGE);
	gnome_config_set_bool(path, set->objPropPlanes);
	g_snprintf(path, 255, "/%s/game/objHelicopters", PACKAGE);
	gnome_config_set_bool(path, set->objHelicopters);
	g_snprintf(path, 255, "/%s/game/objNoflyzones", PACKAGE);
	gnome_config_set_bool(path, set->objNoflyzones);
	g_snprintf(path, 255, "/%s/game/objStormSystem", PACKAGE);
	gnome_config_set_bool(path, set->objStormSystem);
	g_snprintf(path, 255, "/%s/game/objPowerCables", PACKAGE);
	gnome_config_set_bool(path, set->objPowerCables);
	g_snprintf(path, 255, "/%s/game/objGroundFog", PACKAGE);
	gnome_config_set_bool(path, set->objGroundFog);
	g_snprintf(path, 255, "/%s/game/objMountains", PACKAGE);
	gnome_config_set_bool(path, set->objMountains);

	g_snprintf(path, 255, "/%s/game/probEngine", PACKAGE);
	gnome_config_set_bool(path, set->probEngine);
	g_snprintf(path, 255, "/%s/game/probGear", PACKAGE);
	gnome_config_set_bool(path, set->probGear);
	g_snprintf(path, 255, "/%s/game/probTerror", PACKAGE);
	gnome_config_set_bool(path, set->probTerror);
	g_snprintf(path, 255, "/%s/game/probPilot", PACKAGE);
	gnome_config_set_bool(path, set->probPilot);
	g_snprintf(path, 255, "/%s/game/probAlien", PACKAGE);
	gnome_config_set_bool(path, set->probAlien);
	g_snprintf(path, 255, "/%s/game/probBrids", PACKAGE);
	gnome_config_set_bool(path, set->probBrids);

	g_snprintf(path, 255, "/%s/setup/minPlaneDist", PACKAGE);
	gnome_config_set_int(path, set->initMinPlaneDist);
	
	highScoreWrite(set->highScore);
	gnome_config_sync();
	g_print("Wrote preference file\n");
}

void /* load in a normal preference file */
prefReadNormal(airSetting* set) {

	gchar path[256];

	g_assert(set);
	g_print("Reading normal preference file\n");

	g_snprintf(path, 255, "/%s/game/roundSpeed=%d", PACKAGE, AIR_ROUNDSPEED);
	set->roundSpeed = gnome_config_get_int(path);
	g_snprintf(path, 255, "/%s/game/duration=%d", PACKAGE, AIR_GAMEDURATION);
	set->gameDuration = gnome_config_get_int(path);
	g_snprintf(path, 255, "/%s/game/nrOfAircraft=%d", PACKAGE, AIR_NROFAIRCRAFT);
	set->planeNr = gnome_config_get_int(path);
	g_snprintf(path, 255, "/%s/game/nrOfAirport=%d", PACKAGE, AIR_NROFAIRPORT);
	set->airportNr = gnome_config_get_int(path);
	g_snprintf(path, 255, "/%s/game/missDist=%d", PACKAGE, AIR_MISSDIST);
	set->missDist =	gnome_config_get_int(path);
	g_snprintf(path, 255, "/%s/game/crashDist=%d", PACKAGE, AIR_CRASHDIST);
	set->crashDist = gnome_config_get_int(path);
	g_snprintf(path, 255, "/%s/setup/minPlaneDist=%d", PACKAGE, AIR_INITMINPLANEDIST);
	set->initMinPlaneDist =	gnome_config_get_int(path);

	g_snprintf(path, 255, "/%s/setup/objJetplane=false", PACKAGE);
	set->objJetplane =	gnome_config_get_bool(path);
	g_snprintf(path, 255, "/%s/setup/objPropPlanes=false", PACKAGE);
	set->objPropPlanes =	gnome_config_get_bool(path);
	g_snprintf(path, 255, "/%s/setup/objHelicopters=false", PACKAGE);
	set->objHelicopters =	gnome_config_get_bool(path);
	g_snprintf(path, 255, "/%s/setup/objNoflyzones=false", PACKAGE);
	set->objNoflyzones =	gnome_config_get_bool(path);
	g_snprintf(path, 255, "/%s/setup/objStormSystem=false", PACKAGE);
	set->objStormSystem =	gnome_config_get_bool(path);
	g_snprintf(path, 255, "/%s/setup/objPowerCables=false", PACKAGE);
	set->objPowerCables =	gnome_config_get_bool(path);
	g_snprintf(path, 255, "/%s/setup/objGroundFog=false", PACKAGE);
	set->objGroundFog =	gnome_config_get_bool(path);
	g_snprintf(path, 255, "/%s/setup/objMountains=false", PACKAGE);
	set->objMountains =	gnome_config_get_bool(path);

	g_snprintf(path, 255, "/%s/setup/probEngine=false", PACKAGE);
	set->probEngine =	gnome_config_get_bool(path);
	g_snprintf(path, 255, "/%s/setup/probGear=false", PACKAGE);
	set->probGear =	        gnome_config_get_bool(path);
	g_snprintf(path, 255, "/%s/setup/probTerror=false", PACKAGE);
	set->probTerror =	gnome_config_get_bool(path);
	g_snprintf(path, 255, "/%s/setup/probPilot=false", PACKAGE);
	set->probPilot =	gnome_config_get_bool(path);
	g_snprintf(path, 255, "/%s/setup/probAlien=false", PACKAGE);
	set->probAlien =	gnome_config_get_bool(path);
	g_snprintf(path, 255, "/%s/setup/probBrids=false", PACKAGE);
	set->probBrids =	gnome_config_get_bool(path);

	g_snprintf(path, 255, "/%s/setup/minPlaneDist=%d", PACKAGE, AIR_INITMINPLANEDIST);
	set->initMinPlaneDist =	gnome_config_get_int(path);
	
	set->highScore = highScoreRead();
}

void /* load in an older preference file, trying to get as much info as possible. */
prefReadLegacy(airSetting* set, gchar* version) {

	g_assert(set);
	g_assert(version);

	if(strcmp(version, "0") == 0) {
		g_print(_("No preference file found, using the defaults\n"));
		prefLoadDefaults(set);
	} else {
		g_print(_("Cannot resolve the preference file version, using the defaults"));
	}
}

void /* load the defaults into the structure */
prefLoadDefaults(airSetting* set) {

	g_assert(set);
	
	set->roundSpeed       = AIR_ROUNDSPEED;
	set->gameDuration     = AIR_GAMEDURATION;
	set->planeNr          = AIR_NROFAIRCRAFT;
	set->airportNr        = AIR_NROFAIRPORT;
	set->averageFuel      = AIR_AVERAGEFUEL;
	set->missDist         = AIR_MISSDIST;
	set->crashDist        = AIR_CRASHDIST;
	set->initMinPlaneDist = AIR_INITMINPLANEDIST;

	set->objJetplane =	TRUE;
	set->objPropPlanes =	FALSE;
	set->objHelicopters =	FALSE;
	set->objNoflyzones =	FALSE;
	set->objStormSystem =	FALSE;
	set->objPowerCables =	FALSE;
	set->objGroundFog =	FALSE;
	set->objMountains =	FALSE;
	set->probEngine =	FALSE;
	set->probGear =         FALSE;
	set->probTerror =	FALSE;
	set->probPilot =	FALSE;
	set->probAlien =	FALSE;
	set->probBrids =	FALSE;
		
	set->highScore        = NULL;
}


/* ChangLog
 * --------
 * $Log: prefs.c,v $
 * Revision 1.6  2000/04/20 22:44:31  marijn
 * Fixed settigns init problem and fixed some small compiler warnings.
 *
 * Revision 1.5  2000/04/20 21:59:54  marijn
 * fixed a bug, preventing the reading of the preference file.
 *
 * Revision 1.4  2000/04/19 20:41:40  marijn
 * Added the proper callbacks when WM closes windows. Updated preferences
 *
 * Revision 1.3  2000/04/19 05:54:44  marijn
 * Functioning preferences in a new preference window.
 *
 * Revision 1.2  2000/04/16 17:50:05  marijn
 * Fixed compilation problems.
 *
 * Revision 1.1  2000/04/16 17:12:31  marijn
 * Added support for saving preferences and highscores to preference files.
 *
 */

