/* Various test functions
 * $Id: tests.c,v 1.3 2000/04/27 19:39:16 marijn Exp $

 * An air traffic simulation game. 
 * Copyright (C) 2000  Marijn Vriens <marijn@sanity.dhs.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <math.h>
#include "gnome.h"

#include "defaults.h"
#include "datastructs.h"
#include "utils.h"

gint /* check if the planes are not comming to close to eachother */
testPlanesDist(GList *list, /* returns true, if the false if the plane
			     * is too close */
	       airPlane *plane)
{
	vector a, b;
	airPlane *temp;
	gint dist, mindist = G_MAXINT;
	g_assert(plane); /* die if the plane is a null pointer */
	if (list == NULL){ /* return the maximum if the list doesn't exist (yet) */
		return mindist;
	}	
	a = plane->in->pos;
	list = g_list_first(list);
	do {
		temp = list->data;
		b = temp->in->pos;
		dist = floor(objDist(a,b)+0.5);
/* muliply the distance by the difference in time that they occure */
		dist += ( abs( temp->inTime - plane->inTime ) / airSet->roundSpeed );
		if(dist < mindist) {
			mindist = dist;
		}
	} while ((list = g_list_next(list)) != NULL);
	return mindist;
}

gboolean /* tests wether a vector is actively part of the game or
	    not. returns TRUE if it's active and FALSE otherwise. */ 
testVectorActive(vector vec) {
	if( ( vec.x == -1 ) &&
	    ( vec.y == -1 ) &&
	    ( vec.z == -1 ) ) {
		g_assert(vec.x == -1);
		g_assert(vec.y == -1);
		g_assert(vec.z == -1);
		return FALSE;
	} else {
		g_assert(vec.x != -1);
		g_assert(vec.y != -1);
		g_assert(vec.z != -1);
		return TRUE;
	}

}

gboolean /* tests if a vector is within the limits of the
	    board. return TRUE if it is and FALSE otherwise */ 
testVectorOnBoard(vector vec) {
	if( (vec.x < 0) || (vec.x >= AIR_BOARD_X) ||
	    (vec.y < 0) || (vec.y >= AIR_BOARD_Y) ) {
		return FALSE;
	} else {
		return TRUE;
	}
}

gboolean /* did the plane change course. Returns TRUE if it did, and
	    FALSE if it didn't.  */
testPlaneCourseChange(airPlane *plane)
{
	g_assert(plane);
	if( (plane->cmd.heading == -1) && (plane->cmd.z == -1) ) {
		return FALSE;
	} else {
		return TRUE;
	}
}

gint /* compare the times between two planes,
     * used for sorting */
testTimes(gconstpointer a, gconstpointer b) 
{
	const airPlane *one = a;
	const airPlane *two = b;

	g_assert(a);
	g_assert(b);

	if(one->inTime == two->inTime) {
		return 0;
	} else if(one->inTime < two->inTime) {
		return -1;
	} else if(one->inTime > two->inTime) {
		return 1;
	}
	g_assert_not_reached();
	return 0;
}


gint /* compare the scores between games,
      * used for sorting */
testHighScore(gconstpointer a, gconstpointer b) {
	const airHighScore *one = a;
	const airHighScore *two = b;

	g_assert(a);
	g_assert(b);

	if(one->score == two->score) {
		return 0;
	} else if(one->score < two->score) {
		return 1;
	} else if(one->score < two->score) {
		return -1;
	}
	g_assert_not_reached();
	return 0;
}

/* ChangLog
 * $Log: tests.c,v $
 * Revision 1.3  2000/04/27 19:39:16  marijn
 * Added asserts to catch wrong function calling.
 *
 * Revision 1.2  2000/04/16 17:12:31  marijn
 * Added support for saving preferences and highscores to preference files.
 *
 * Revision 1.1  2000/04/02 02:11:33  marijn
 * Major source code reordering, added license information.
 *
 */
