/* Non program specific functions
 * $Id: utils.c,v 1.4 2000/04/27 20:26:51 marijn Exp $

 * An air traffic simulation game. 
 * Copyright (C) 2000  Marijn Vriens <marijn@sanity.dhs.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <math.h>
#include "gnome.h"

#include "defaults.h"
#include "datastructs.h"

char * /* format seconds to nice human readable time */
secsToMinutes(gint time)
{
	gchar *text = NULL;
	gint minutes, secs;
	gboolean neg = FALSE;

	if(time < 0) {
		time = ABS(time);
		neg  = TRUE;
	}

	minutes = time / 60;
	secs    = time - ( minutes * 60 );
	if(neg) {
		text = g_strdup_printf("-%02d:%02d", minutes, secs);
	} else {
		text = g_strdup_printf("%02d:%02d", minutes, secs);
				
	}
		return text;
}

float /* calculate the distance between 2 points */
objDist(vector a,
	vector b) 
{       
	return( sqrt( pow( (a.x - b.x), 2 ) + 
		      pow( (a.y - b.y), 2 ) + 
		      pow( (a.z - b.z), 2 ) ) );
}

char * /* put human readable froms of text insted of the cold
	* degrees themselfs. */
degsToHeading(gint heading)
{
	gchar *text = NULL;
	switch(heading) {
	case 0: 
		text = g_strdup_printf("n");
		break;
	case 45:
		text = g_strdup_printf("ne");
		break;
	case 90:
		text = g_strdup_printf("e");
		break;
	case 135:
		text = g_strdup_printf("se");
		break;
	case 180:
		text = g_strdup_printf("s");
		break;
	case 225:
		text = g_strdup_printf("sw");
		break;
	case 270:
		text = g_strdup_printf("w");
		break;
	case 315:
		text = g_strdup_printf("nw");
		break;
	default:
		text = g_strdup_printf("%03d", heading);
		
	}
	return text;
}

gint
calc_plane_score(airSetting *set) {
	gdouble value = 0;

	g_assert(set);
	g_assert(set->roundSpeed   != 0);
	g_assert(set->gameDuration != 0);
	
/*  formula:       (nrOfAirport+1)       30           15
 *           100 * --------------- * ---------- * ------------ * (nearMissDist+1) = value
 *                        2          Roundspeed   GameDuration
 */

	value = 100* ( (gdouble) ( (set->airportNr + 1) * 30 * 15 ) /
		       ( 2 * set->roundSpeed * set->gameDuration) *
		       (set->missDist + 1) );

//	g_print("airportNr = %d, roundSpeed = %d, gameDuration = %d, missDist = %d, value = %g\n",
//		set->airportNr,
//		set->roundSpeed,
//		set->gameDuration,
//		set->missDist,
//		value);

	
	return( (gint) value);
}

gint
calc_max_score(airSetting *set) {
	gint value;

	value = set->planeNr * calc_plane_score(set);

	return value;
}

/* ChangeLog
 * $Log: utils.c,v $
 * Revision 1.4  2000/04/27 20:26:51  marijn
 * fixed a bug in secsToMinutes. Negative values are now represented -xx:xx
 *
 * Revision 1.3  2000/04/24 17:32:07  marijn
 * Removed debugging noise.
 *
 * Revision 1.2  2000/04/20 18:57:07  marijn
 * Scores per plane and maximum are now shown according the game settings.
 *
 * Revision 1.1  2000/04/02 02:11:33  marijn
 * Major source code reordering, added license information.
 *
 */
